@@ -31,7 +31,6 @@ void on_mni_session_file_open_activate (GtkMenuItem *menuitem, gpointer user_dat
 void on_mni_antispam (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_Functions_number_hex2dec (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_config_open (GtkMenuItem *menuitem, gpointer user_data);
-void on_mni_open_in_browser (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_Markup_link_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_utils_stats (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_Functions_number_bin2dec (GtkMenuItem *menuitem, gpointer user_data);
@@ -224,8 +223,30 @@ void select_charset_fileopen (GtkComboBox *combobox, gpointer user_data);
 void select_charset_filesave (GtkComboBox *combobox, gpointer user_data);
 void on_mni_ins_ast (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_text_to_html_fmt (GtkMenuItem *menuitem, gpointer user_data);
-
 GtkWidget* lookup_widget2 (GtkContainer *widget, const gchar *widget_name);
 void on_bt_open (GtkButton *button, gpointer user_data);
 void on_mni_fam_open (GtkMenuItem *menuitem, gpointer user_data);
-
+void on_mni_fullscreen (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_unfullscreen (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_copied_html_to_ftext (GtkMenuItem* menuitem, gpointer user_data);
+void on_mni_move_line_up (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_move_line_down (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_save_all (GtkMenuItem *menuitem, gpointer user_data);
+gboolean save_all_cb (gpointer data);
+void tea_file_open_dialog (void);
+void tea_file_save_dialog (int mode);
+void on_mni_paint (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_copy_painted (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_unpaint_all (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_search_and_paint (GtkMenuItem* menuitem, gpointer user_data);
+void on_mni_paint_lines_bigger_than (GtkMenuItem* menuitem, gpointer user_data);
+void event_after (GtkWidget *widget, GdkEvent *event, gpointer user_data);
+void on_mni_ext_programs_menu_item (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_ext_programs_file_open (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_mark_each_n_line (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_crashfile_open (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_mark_all_lines_with_string (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_suggest (GtkMenuItem *menuitem, gpointer user_data);
+void on_bt_close_current_doc (GtkButton *button, gpointer user_data);
+void on_mni_hide_error_marks (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_spellcheck_def (GtkMenuItem *menuitem, gpointer user_data);
