@@ -3,7 +3,7 @@
                              -------------------
     begin                : 2003
     copyright            : (C)2003, 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
  ***************************************************************************/
 
 /***************************************************************************
@@ -23,11 +23,11 @@
 #include <glib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "callbacks.h"
 #include "interface.h"
 #include "tea_defs.h"
-#include "tea_text_document.h"
 #include "tea_config.h"
 #include "tea_funx.h"
 #include "tea_gtk_utils.h"
@@ -40,6 +40,11 @@ enum
 };
 
 
+void ui_update (void)
+{
+  tea_widget_show (bt_close_current_doc, confile.common_closing_button_visible);
+}
+
 static gboolean mpb_bounce (gpointer data)
 {
   gtk_progress_bar_pulse (pb_status);   
@@ -81,7 +86,7 @@ static GtkWidget* create_hardcoded_toolbar (void)
 
   gtk_toolbar_insert_stock (toolbar, GTK_STOCK_SAVE_AS, _("Save as a different name"), NULL, file_save_as, NULL, 0);
   gtk_toolbar_insert_stock (toolbar, GTK_STOCK_SAVE, _("Save a current file"), NULL, file_save, NULL, 0);
-  gtk_toolbar_insert_stock (toolbar, GTK_STOCK_OPEN, _("Open a file"), NULL, file_open, NULL, 0);
+  gtk_toolbar_insert_stock (toolbar, GTK_STOCK_OPEN, _("Open a file"), NULL, tea_file_open_dialog, NULL, 0);
   gtk_toolbar_insert_stock (toolbar, GTK_STOCK_NEW, _("Create a new file"), NULL, file_new, NULL, 0);
 
   gtk_toolbar_set_style (toolbar, GTK_TOOLBAR_ICONS); 
@@ -141,11 +146,30 @@ GtkWidget* create_tea_main_window (void)
   gtk_widget_show (mainvbox);
   gtk_container_add (GTK_CONTAINER (tea_main_window), mainvbox);
 
+  GtkWidget *hb_topbox = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (hb_topbox);
+  gtk_box_pack_start (GTK_BOX (mainvbox), hb_topbox, FALSE, FALSE, UI_PACKFACTOR);
+
+  bt_close_current_doc = tea_stock_button (GTK_STOCK_CLOSE);
+  g_signal_connect ((gpointer) bt_close_current_doc, "clicked",
+                    G_CALLBACK (on_bt_close_current_doc),
+                    NULL);
+
+
   menubar1 = gtk_menu_bar_new ();
 
   gtk_widget_set_name (menubar1, "menubar1");
   gtk_widget_show (menubar1);
-  gtk_box_pack_start (GTK_BOX (mainvbox), menubar1, FALSE, FALSE, UI_PACKFACTOR);
+
+//  gtk_box_pack_start (GTK_BOX (mainvbox), menubar1, FALSE, FALSE, UI_PACKFACTOR);
+  gtk_box_pack_start (GTK_BOX (hb_topbox), menubar1, FALSE, FALSE, UI_PACKFACTOR);
+  gtk_box_pack_start (GTK_BOX (hb_topbox), bt_close_current_doc, FALSE, FALSE, UI_PACKFACTOR);
+ 
+  gtk_tooltips_set_tip (tooltips,
+                        bt_close_current_doc,
+                        _("Close a current document"),
+                        NULL);  
+
 
   mni_temp = new_menu_item (_("File"), menubar1, NULL);
   mni_file_menu = new_menu_submenu (mni_temp);
@@ -161,7 +185,7 @@ GtkWidget* create_tea_main_window (void)
                               GDK_N, GDK_MOD1_MASK,
                               GTK_ACCEL_VISIBLE);
 
-  //mni_temp = new_menu_item (_("test"), mni_file_menu, on_mni_test);
+//  mni_temp = new_menu_item (_("test"), mni_file_menu, on_mni_test);
     
   mni_temp = new_menu_item (_("Crapbook"), mni_file_menu, on_mni_file_crapbook);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
@@ -189,7 +213,7 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Open template"), mni_opendifferent_menu, on_mni_templ_file_open_activate);
   mni_temp = new_menu_item (_("Open session file"), mni_opendifferent_menu, on_mni_session_file_open_activate);
   mni_temp = new_menu_item (_("Open from the Famous text entry"), mni_opendifferent_menu, on_mni_fam_open);  
-
+  
   mni_temp = new_menu_sep (mni_file_menu);
 
   mni_recent_list = new_menu_item (_("Recent files"), mni_file_menu, NULL);
@@ -230,30 +254,32 @@ GtkWidget* create_tea_main_window (void)
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
                               GDK_b, GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
-
+  
+  mni_temp = new_menu_item (_("Save all"), mni_savedifferent_menu, on_mni_save_all);
+ 
   mni_temp = new_menu_item (_("Revert to saved"), mni_file_menu, on_mni_file_revert_to_saved);
 
   mni_temp = new_menu_sep (mni_file_menu);
 
-  mni_temp = new_menu_item (_("Manage config files"), mni_file_menu, NULL);
+  mni_temp = new_menu_item (_("Manage utility files"), mni_file_menu, NULL);
   mni_file_configs_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_item (_("Autoreplace words file"), mni_file_configs_menu, on_mni_autorep_file_open);
   mni_temp = new_menu_item (_("Autosaving list"), mni_file_configs_menu, on_mni_autosave_list_open);
   mni_temp = new_menu_item (_("Main config"), mni_file_configs_menu , on_mni_config_open);
   mni_temp = new_menu_item (_("Hotkeys config"), mni_file_configs_menu, on_mni_open_hotkeys);
-  mni_temp = new_menu_item (_("User-menu config"), mni_file_configs_menu, on_mni_user_menu_open);
+  mni_temp = new_menu_item (_("External programs list config"), mni_file_configs_menu, on_mni_ext_programs_file_open);
   mni_temp = new_menu_item (_("Bookmarks file"), mni_file_configs_menu, on_mni_file_open_bookmark);
-  mni_temp = new_menu_item (_("Kwas bookmarks config"), mni_file_configs_menu, on_mni_open_kwas_bookmarks_file);
-
+  mni_temp = new_menu_item (_("Open the crashfile"), mni_file_configs_menu, on_mni_crashfile_open);  
+  
   mni_temp = new_menu_item (_("Preferences"), mni_file_menu, on_mni_show_options);
  
   mni_temp = new_menu_sep (mni_file_menu);
 
   mni_temp = new_menu_item (_("Close current"), mni_file_menu, on_mni_file_close_current);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
-                              GDK_Q, GDK_MOD1_MASK,
+                              GDK_w, GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
-
+  
   mni_temp = new_menu_item (_("Close all"), mni_file_menu, on_mni_file_close_all);
 /*
   GtkActionGroup *ag_file = gtk_action_group_new ("file");
@@ -292,8 +318,25 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Cut!"), mni_edit_menu, on_mni_edit_cut);
   mni_temp = new_menu_item (_("Paste"), mni_edit_menu, on_mni_paste);
   mni_temp = new_menu_item (_("Swop"), mni_edit_menu,on_mni_edit_replace_with_clipboard);
+
+  mni_temp = new_menu_sep (mni_edit_menu);
+  mni_temp = new_menu_item (_("Move line up"), mni_edit_menu, on_mni_move_line_up);
+  gtk_widget_add_accelerator (mni_temp, "activate", accel_group, GDK_Up, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+  mni_temp = new_menu_item (_("Move line down"), mni_edit_menu, on_mni_move_line_down);
+  gtk_widget_add_accelerator (mni_temp, "activate", accel_group, GDK_Down, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
   
-  
+  mni_temp = new_menu_sep (mni_edit_menu);
+
+  mni_temp = new_menu_item (_("Marking"), mni_edit_menu, NULL);
+  mni_mark_menu = new_menu_submenu (mni_temp);
+  mni_temp = new_menu_tof (mni_mark_menu);
+ 
+  mni_temp = new_menu_item (_("Mark"), mni_mark_menu, on_mni_paint);
+  mni_temp = new_menu_item (_("Copy marked"), mni_mark_menu, on_mni_copy_painted);
+  mni_temp = new_menu_item (_("Unmark all"), mni_mark_menu, on_mni_unpaint_all);
+  mni_temp = new_menu_item (_("Mark each n-th line"), mni_mark_menu, on_mni_mark_each_n_line);
+  mni_temp = new_menu_item (_("Mark lines those contains a string"), mni_mark_menu, on_mni_mark_all_lines_with_string);
+
   mni_temp = new_menu_sep (mni_edit_menu);
 
   mni_temp = new_menu_item (_("Cut to new"), mni_edit_menu, on_mni_cut_to_new);
@@ -350,11 +393,15 @@ GtkWidget* create_tea_main_window (void)
                               GDK_F3, GDK_SHIFT_MASK,
                               GTK_ACCEL_VISIBLE);
 
+  mni_temp = new_menu_item (_("Find and mark"), mni_quest_menu, on_mni_search_and_paint);
+  mni_temp = new_menu_item (_("Mark lines > n characters"), mni_quest_menu, on_mni_paint_lines_bigger_than);
+  
   mni_temp = new_menu_item (_("Goto line"), mni_quest_menu, on_mni_goto_line);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
                               GDK_g, GDK_MOD1_MASK,
                               GTK_ACCEL_VISIBLE);
 
+
   mni_temp = new_menu_item (_("Replace all"), mni_quest_menu, on_mni_search_repall);
 
   mni_temp = new_menu_item (_("Scan for local links"), mni_quest_menu, on_mni_get_links );
@@ -569,9 +616,18 @@ GtkWidget* create_tea_main_window (void)
                               GDK_F11, 0,
                               GTK_ACCEL_VISIBLE);
 
-  mni_spellcheck = new_menu_item (_("Spell check"), mni_functions_menu, NULL);
+
+  mni_temp = new_menu_sep (mni_functions_menu);
+
+  mni_spellcheck = new_menu_item (_("Spell-checker languages"), mni_functions_menu, NULL);
   mni_spellcheck_menu = new_menu_submenu (mni_spellcheck);
 
+  mni_temp = new_menu_item (_("Spell check"), mni_functions_menu, on_mni_spellcheck_def);
+
+  mni_temp = new_menu_item (_("Suggest a word"), mni_functions_menu, on_mni_suggest);
+
+  mni_temp = new_menu_sep (mni_functions_menu);
+
   mni_ide = new_menu_item (_("IDE"), mni_functions_menu, NULL);
   mni_ide_menu = new_menu_submenu (mni_ide);
   mni_temp = new_menu_tof (mni_ide_menu);
@@ -582,7 +638,7 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Save project as"), mni_ide_menu, on_mni_project_save_as);
   mni_temp = new_menu_item (_("Project properties"), mni_ide_menu, on_mni_show_project_props);
   mni_temp = new_menu_item (_("Make"), mni_ide_menu, on_mni_project_make);
-  mni_temp = new_menu_item (_("Run"), mni_ide_menu, on_mni_show_project_run);
+  mni_temp = new_menu_item (_("Execute"), mni_ide_menu, on_mni_show_project_run);
  
   mni_temp = new_menu_item (_("UNIversal Text AnalyZer"), mni_functions_menu, NULL);
   mni_utils_unitaz_menu = new_menu_submenu (mni_temp);
@@ -599,9 +655,6 @@ GtkWidget* create_tea_main_window (void)
   mni_snippets = new_menu_item (_("Snippets"), mni_functions_menu, NULL);
   mni_snippets_menu = new_menu_submenu (mni_snippets);
 
-  mni_user_menu = new_menu_item (_("User menu"), mni_functions_menu, NULL);
-  mni_user_menu_menu = new_menu_submenu (mni_user_menu);
-
   mni_temp = new_menu_sep (mni_functions_menu);
 
   mni_temp = new_menu_item (_("Insert"), mni_functions_menu, NULL);
@@ -661,6 +714,8 @@ GtkWidget* create_tea_main_window (void)
   mni_format_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_tof (mni_format_menu);
 
+  mni_temp = new_menu_item (_("Browser to text"), mni_format_menu, on_mni_copied_html_to_ftext);
+  
   mni_temp = new_menu_item (_("Kill formatting"), mni_format_menu, on_mni_kill_formatting);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
                               GDK_D, GDK_MOD1_MASK,
@@ -742,22 +797,9 @@ GtkWidget* create_tea_main_window (void)
   mni_tabs = new_menu_item (_("Tabs"), menubar1, NULL);
   mni_tabs_menu = new_menu_submenu (mni_tabs);
 
-  mni_temp = new_menu_item (_("Bro"), menubar1, NULL);
-  mni_bro_menu = new_menu_submenu (mni_temp);
+  mni_ext_programs = new_menu_item (_("Run"), menubar1, NULL);
+  mni_ext_programs_menu = new_menu_submenu (mni_ext_programs);
 
-  mni_temp = new_menu_tof (mni_bro_menu);
-  mni_temp = new_menu_item ("Opera", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Konqueror", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Firefox", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Mozilla", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Galeon", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Dillo", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Elinks", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Links", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Lynx", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Epiphany", mni_bro_menu, on_mni_open_in_browser);
-  mni_temp = new_menu_item ("Other", mni_bro_menu, on_mni_open_in_browser);
-  
   mni_temp = new_menu_item (_("Nav"), menubar1, NULL);
   mni_nav_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_tof (mni_nav_menu);
@@ -799,9 +841,12 @@ GtkWidget* create_tea_main_window (void)
   mni_view_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_tof (mni_view_menu);
  
-  mni_co = new_menu_item (_("Co"), mni_view_menu, NULL);
+  mni_co = new_menu_item (_("Encoding"), mni_view_menu, NULL);
   mni_co_menu = new_menu_submenu (mni_co);
 
+#ifndef CHAI_MODE
+
+
   mni_temp = new_menu_item (_("Highlighting mode"), mni_view_menu, NULL);
   mni_hl_mode_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_item (HL_NONE, mni_hl_mode_menu, on_mni_set_hl_mode);
@@ -821,6 +866,11 @@ GtkWidget* create_tea_main_window (void)
 
   mni_temp = new_menu_item (_("Hide highlighting"), mni_view_menu, on_mni_view_hide_highlighting);
 
+#endif
+
+
+  mni_temp = new_menu_item (_("Hide error marks"), mni_view_menu, on_mni_hide_error_marks);
+
   mni_temp = new_menu_item (_("Word wrap"), mni_view_menu, on_mni_view_wrap);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
                               GDK_W, GDK_MOD1_MASK,
@@ -831,8 +881,9 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item ("Imageplane", mni_view_menu, on_mni_imageplane);
   mni_temp = new_menu_item (_("Switch header/source"), mni_view_menu, on_source_header_switch);
   mni_temp = new_menu_item (_("Preview with Mplayer"), mni_view_menu, on_mni_nav_mplayer_jump);
-    
- 
+  mni_temp = new_menu_item (_("Fullscreen"), mni_view_menu, on_mni_fullscreen);
+  mni_temp = new_menu_item (_("Un-fullscreen"), mni_view_menu, on_mni_unfullscreen);
+
   mni_temp = new_menu_item (_("Help"), menubar1, NULL);
   mni_what_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_tof (mni_what_menu);
@@ -848,18 +899,23 @@ GtkWidget* create_tea_main_window (void)
 
   tb_main_toolbar = create_hardcoded_toolbar ();
   gtk_box_pack_start (GTK_BOX (mainvbox), tb_main_toolbar, FALSE, TRUE, UI_PACKFACTOR);
+
   
   vpaned1 = gtk_vpaned_new ();
   gtk_widget_show (vpaned1);
   gtk_box_pack_start (GTK_BOX (mainvbox), vpaned1, TRUE, TRUE, UI_PACKFACTOR);
   gtk_paned_set_position (GTK_PANED (vpaned1), 0);
 
+
+
   notebook1 = gtk_notebook_new ();
   gtk_widget_set_name (notebook1, "notebook1");
   gtk_widget_show (notebook1);
    
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook1), TRUE);
 
+
+
   gtk_paned_pack1 (GTK_PANED (vpaned1), notebook1, TRUE, TRUE);
   
   vbox2 = gtk_vbox_new (FALSE, UI_PACKFACTOR);
@@ -868,6 +924,7 @@ GtkWidget* create_tea_main_window (void)
   
   scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
   gtk_widget_show (scrolledwindow3);
+
   gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow3, TRUE, TRUE, UI_PACKFACTOR);
 
   tv_logmemo = gtk_text_view_new ();
@@ -881,14 +938,12 @@ GtkWidget* create_tea_main_window (void)
   GtkWidget *fam_hbox = gtk_hbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (fam_hbox);
   gtk_box_pack_start (GTK_BOX (vbox2), fam_hbox, FALSE, FALSE, UI_PACKFACTOR);
-    
+
+   
   ent_search = gtk_entry_new ();   
   gtk_widget_show (ent_search);
-  
   gtk_box_pack_start (GTK_BOX (fam_hbox), ent_search, TRUE, TRUE, UI_PACKFACTOR);
 
-
-  //GtkWidget* fam_button = gtk_button_new_from_stock (GTK_STOCK_EXECUTE);
   GtkWidget* bt_fam = tea_stock_button (GTK_STOCK_EXECUTE);
   gtk_widget_show (bt_fam);
   gtk_box_pack_start (GTK_BOX (fam_hbox), bt_fam, FALSE, FALSE, UI_PACKFACTOR);
@@ -897,7 +952,6 @@ GtkWidget* create_tea_main_window (void)
                     G_CALLBACK (on_doit_button),
                     NULL);
 
-
   GtkWidget* bt_open = tea_stock_button (GTK_STOCK_OPEN);
   gtk_widget_show (bt_open);
   gtk_box_pack_start (GTK_BOX (fam_hbox), bt_open, FALSE, FALSE, UI_PACKFACTOR);
@@ -906,7 +960,6 @@ GtkWidget* create_tea_main_window (void)
                     G_CALLBACK (on_bt_open),
                     NULL);
 
-
   gtk_tooltips_set_tip (tooltips,
                         bt_fam,
                         _("Click here to search this through the text"),
@@ -917,7 +970,6 @@ GtkWidget* create_tea_main_window (void)
                         _("Click here to open a file"),
                         NULL);
 
-
   g_signal_connect ((gpointer) ent_search, "key_press_event",
                     G_CALLBACK (on_ent_search_key_press_event),
                     NULL);
@@ -934,6 +986,7 @@ GtkWidget* create_tea_main_window (void)
                     G_CALLBACK (on_notebook1_switch_page),
                     NULL);
 
+
   gtk_window_add_accel_group (GTK_WINDOW (tea_main_window), accel_group);
 
   set_dnd_accept (tea_main_window);
@@ -947,11 +1000,15 @@ GtkWidget* create_tea_main_window (void)
                                              "foreground", "red", NULL);
 
   gtk_text_buffer_create_tag (log_memo_textbuffer, "lm_normal",
-                              "foreground", "black", NULL);
+                              "foreground", confile.text_foreground, NULL);
 
   gtk_text_buffer_create_tag (log_memo_textbuffer, "lm_advice",
                               "foreground", "navy", NULL);
 
+  gtk_text_buffer_create_tag (log_memo_textbuffer, "lm_bold",
+                              "foreground", confile.text_foreground, "font", "bold", NULL);
+
+
   set_lm_colors ();
   widget_apply_colors (tv_logmemo);
   widget_apply_colors (ent_search);
@@ -960,10 +1017,21 @@ GtkWidget* create_tea_main_window (void)
                     G_CALLBACK (cb_logmemo_button_press_event),
                     tv_logmemo);
 
+
   log_to_memo (_("PLEASE read the manual :)"), NULL, LM_GREET);
-  log_to_memo ("(C)2000-2005 Peter 'Roxton' Semiletov <roxton@ua.fm>", NULL, LM_GREET);
-  log_to_memo ("TEA 9.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
-    
+  log_to_memo ("<peter.semiletov@gmail.com>", NULL, LM_GREET);
+  log_to_memo ("(C)2000-2005 Peter Semiletov", NULL, LM_GREET);
+  
+#ifdef CHAI_MODE
+
+log_to_memo ("TEA 11.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
+
+#else
+
+log_to_memo ("TEA (original) 11.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
+
+#endif
+  
   ui_init ();
 
   gtk_entry_set_text (ent_search, "");  
@@ -975,7 +1043,6 @@ GtkWidget* create_tea_main_window (void)
 
   if (g_file_test (TEA_PIX_MAINICON, G_FILE_TEST_EXISTS))
      gtk_window_set_default_icon_from_file (TEA_PIX_MAINICON, NULL);
-  
+
   return tea_main_window;
 }
-
