@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Oct 17 12:08:36 EEST 2003
     copyright            : (C) 2003, 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
 ***************************************************************************/
 
 /*
@@ -42,7 +42,7 @@ Alejandro Dubrovsky <s328940@student.uq.edu.au>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <sys/stat.h>
-
+#include <glib/gi18n.h>
 #include "rox_strings.h"
 #include "tea_defs.h"
 #include "tea_config.h"
@@ -458,7 +458,10 @@ GList* str_in_glist (GList *list, gchar *st)
   while (p)
         {
          if (g_utf8_collate (st, p->data) == 0)
-            result = p;
+            {
+             result = p;
+             break;
+            }
          p = g_list_next (p);
         }
 
@@ -809,7 +812,8 @@ void run_extract_words (t_note_page *page)
 
   while (gtk_text_iter_forward_char (&start)); 
              
-  g_hash_table_foreach (words, str_walk_extract_word, NULL);
+  if (words)
+     g_hash_table_foreach (words, str_walk_extract_word, NULL);
   
   GList *tmplist = g_list_first (g_list_reverse (l_words));
   while (tmplist)
@@ -913,8 +917,10 @@ void run_unitaz (t_note_page *page, gint sort_type, gboolean case_insensetive)
     
   gint i;
   gchar *st = NULL;
-             
-  g_hash_table_foreach (words, walk_by_words, NULL);
+
+  if (words)             
+     g_hash_table_foreach (words, walk_by_words, NULL);
+
   GList *tl;
    
   list = g_list_prepend (list, g_strdup_printf (_("Text analysis results for %s:"), page->file_name_utf8));
@@ -985,15 +991,18 @@ gchar* parse_rtf_hex_str (const gchar *s)
   if (! s)
      return NULL;
 
+//  gchar *st = strstr (s, "\par");
+//  if (! st)
+  //   return NULL; 
+  
   GString *gs = g_string_sized_new (1048576);   
 
+  gchar *st = s;
   gint i;
   gint c;
   gint code; 
-  gchar *st;
   gchar *hex;
   
-  st = s;
   
   for (i = 0; st[i]; i++)
       {
@@ -1830,10 +1839,10 @@ GList* ht_to_glist (GHashTable *hash_table, gint option)
 {
   glist_strings_free (temp_glist);
   
-  if (option == opt_ht_to_glist_full)
+  if (option == opt_ht_to_glist_full && hash_table)
      g_hash_table_foreach (hash_table, ht_to_glist_cb, NULL);
   else
-      if (option == opt_ht_to_glist_keys)
+      if (option == opt_ht_to_glist_keys && hash_table)
          g_hash_table_foreach (hash_table, ht_to_glist_keys_cb, NULL);
 
   return temp_glist;
@@ -2255,6 +2264,7 @@ gchar* read_xml_text (gchar *filename, gchar *xml_file, gchar *para)
   
   gchar *f = g_strconcat (confile.tmp_dir, G_DIR_SEPARATOR_S, xml_file, NULL);  
   gchar *t = str_file_read (f);
+  
   gchar *r = xml_to_plain_text (t, para);
 
   delete_dir (confile.tmp_dir);
@@ -2421,3 +2431,87 @@ gchar* str_to_html (gchar *buf, gboolean xhtml)
   glist_strings_free (l);
   return r;   
 }
+
+
+gint glist_get_str_pos (GList *list, gchar *st)
+{
+  if (! st || ! list)
+      return 0;
+ 
+  gint c = 0;
+
+  GList *p = g_list_first (list);
+
+  while (p)
+        {
+         if (g_utf8_collate (st, p->data) == 0)
+            break;
+         p = g_list_next (p);
+         ++c;
+        }
+
+  return c;
+}
+
+
+gchar* copied_from_browser_to_ftext (const gchar *s, const gchar *pattern)
+{
+  GList *temp = glist_from_string (s);
+  if (! temp)
+     return NULL; 
+
+  GList *temp2 = remove_blank_lines (temp);
+  temp2 = glist_repl (temp2, pattern);
+  
+  gchar *t = string_from_glist (temp2);
+
+  glist_strings_free (temp);
+  glist_strings_free (temp2);
+  return t;
+} 
+
+
+gchar* get_charset_from_meta (gchar *text)
+{
+  gchar *s1 = strstr (text, "<meta");
+  if (! s1)
+    return NULL;
+
+  s1 = strstr (text, "charset=");
+  if (! s1)
+    return NULL;
+
+  s1 = strstr (s1, "=");
+  if (! s1)
+     return NULL;
+
+   s1++;
+
+  GString *s = g_string_sized_new (64);
+  gint i = -1;
+
+  while ( s1[++i] != '\"' )
+        s = g_string_append_c (s, s1[i]);
+        
+  s1 = g_string_free (s, FALSE);
+
+  return g_strstrip (s1);
+}
+
+
+void gslist_strings_free (GSList *list)
+{
+  if (! list)
+     return;
+
+  GSList *t = list;
+  while (t)
+        {
+         if (t->data)
+            g_free (t->data);
+         t = g_slist_next (t);
+        }
+
+  g_slist_free (t);
+}
+
