@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fir Dec 19 2003
     copyright            : (C) 2003, 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
  ***************************************************************************/
  
 /***************************************************************************
@@ -26,13 +26,19 @@
 #include <sys/stat.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
+
+#ifdef CHAI_MODE
+
+#include <libgnomevfs/gnome-vfs.h>
+
+#endif
 
 #include "callbacks.h"
 #include "interface.h"
 #include "tea_defs.h"
 #include "tea_text_document.h"
 #include "tea_config.h"
-#include "tea_hl.h"
 #include "tea_spell.h"
 #include "tea_proj.h"
 #include "tea_gtk_utils.h"
@@ -40,38 +46,39 @@
 #include "image_browser.h"
 
 
+
 static GHashTable *ht_tea_hotkeys = NULL;
 static GHashTable *tea_options = NULL;
 
 
-static GList* create_supported_markup_modes (void)
+GList* create_supported_markup_modes (void)
 {
-  gl_supported_markup_modes = g_list_append (gl_supported_markup_modes, g_strdup ("HTML")); 
-  gl_supported_markup_modes = g_list_append (gl_supported_markup_modes, g_strdup ("XHTML")); 
-  gl_supported_markup_modes = g_list_append (gl_supported_markup_modes, g_strdup ("Wikipedia")); 
-  gl_supported_markup_modes = g_list_append (gl_supported_markup_modes, g_strdup ("LaTeX")); 
-  gl_supported_markup_modes = g_list_append (gl_supported_markup_modes, g_strdup ("Docbook")); 
-
-  return gl_supported_markup_modes; 
+  GList *l = NULL;
+  l = g_list_append (l, g_strdup ("HTML")); 
+  l = g_list_append (l, g_strdup ("XHTML")); 
+  l = g_list_append (l, g_strdup ("Wikipedia")); 
+  l = g_list_append (l, g_strdup ("LaTeX")); 
+  l = g_list_append (l, g_strdup ("Docbook")); 
+  return l; 
 }
 
 
 void ui_init (void)
 {
-  gl_supported_markup_modes = NULL;
-  gl_supported_markup_modes = create_supported_markup_modes ();
-  
+  gl_markup_modes = create_supported_markup_modes ();
+
+  gl_image_formats = image_formats_fill ();  
+
   cur_tea_project = NULL;
   GList *ui = NULL;
-  gl_famous = NULL;
-  gl_kwas_history = NULL;
   gl_tea_kwas_bookmarks = NULL;
+  mni_suggestions = NULL;
+  temp_text_part = NULL;
 
   ui = load_file_to_glist (confile.tea_ui);
-  gl_famous = load_file_to_glist (confile.tea_gl_famous);
-  gl_kwas_history = load_file_to_glist (confile.tea_kwas_history);
   gl_tea_kwas_bookmarks = load_file_to_glist (confile.tea_kwas_bookmarks);
     
+  confile.def_spell_lang = conf_get_char_value (ui, "def_spell_lang", "en"); 
   confile.last_prefs_tab = conf_get_int_value (ui, "last_prefs_tab", 0); 
 
   gtk_paned_set_position (vpaned1, conf_get_int_value (ui, "vpaned1_y", 300));
@@ -84,13 +91,34 @@ void ui_init (void)
                      conf_get_int_value (ui, "main_wnd_w", 630),
                      conf_get_int_value (ui, "main_wnd_h", 450));
 
+
+  gtk_notebook_set_tab_pos (notebook1, confile.notebook_tab_position);
+
+  if (confile.fullscreen)
+     gtk_window_fullscreen (tea_main_window); 
+
+  g_timeout_add ((60 * 1000) * confile.autosave_interval, save_all_cb, NULL);
   glist_strings_free (ui);
+
+#ifdef CHAI_MODE
+
+  source_languages_manager = gtk_source_languages_manager_new ();
+  gl_supported_hlangs = get_supported_langs ();
+  langs_load ();
+
+#endif
+
+
+  ui_update ();
 }
 
 
 //current music: Scorn - Silver Rain Fell (Meat Beat Manifesto Mix)
 void ui_done (void)
 {
+  if (confile.do_last_session)
+     session_save_to_file (confile.last_session);
+
   GList *list = NULL;
 
   list = add_to_glist_combined_int (list, "vpaned1_y", gtk_paned_get_position  (vpaned1));
@@ -103,6 +131,7 @@ void ui_done (void)
   list = add_to_glist_combined_int (list, "last_prefs_tab", confile.last_prefs_tab);
   list = add_to_glist_combined_int (list, "main_wnd_x", x);
   list = add_to_glist_combined_int (list, "main_wnd_y", y);
+  list = add_to_glist_combined_str (list, "def_spell_lang", confile.def_spell_lang);
 
   gtk_window_get_size (GTK_WINDOW (tea_main_window), &x, &y);
 
@@ -110,20 +139,21 @@ void ui_done (void)
   list = add_to_glist_combined_int (list, "main_wnd_h", y);
   
   glist_save_to_file (list, confile.tea_ui);
-  glist_save_to_file (gl_famous, confile.tea_gl_famous);
-  glist_save_to_file (gl_kwas_history, confile.tea_kwas_history);
-  glist_save_to_file (gl_tea_kwas_bookmarks, confile.tea_kwas_bookmarks);
-  
   glist_strings_free (gl_autosave);
+  g_free (confile.def_spell_lang);
+
   g_list_free (gl_enc_available);
   g_list_free (confile.gl_save_charsets);
   g_list_free (list);
-
   glist_strings_free (gl_enc_choosed);
-  glist_strings_free (gl_famous);
-  glist_strings_free (gl_kwas_history);
   glist_strings_free (gl_tea_kwas_bookmarks);
-  glist_strings_free (gl_supported_markup_modes);
+  glist_strings_free (gl_markup_modes);
+
+  if (temp_text_part)
+     {
+      g_free (temp_text_part->prefix);
+      g_free (temp_text_part);
+     }
 
   tea_proj_free (cur_tea_project);
 }
@@ -217,9 +247,8 @@ gint conf_get_int_value (GList *confdata, gchar *key, gint def)
 //FIXME: need for cleanup
 void confile_free (void)
 {
-  glist_strings_free (confile.confdata);
-
   g_free (confile.dir_thumbs);
+  g_free (confile.def_file_ext);
   
   g_free (confile.cm_pdflatex);
   g_free (confile.cm_dvi_to_ps);
@@ -231,9 +260,8 @@ void confile_free (void)
   
   g_free (confile.tea_choosed_charsets);
   g_free (confile.def_filesave_charset);
-  g_free (confile.tea_kwas_history);
   g_free (confile.tea_kwas_bookmarks);
-  g_free (confile.user_menu_file);
+  g_free (confile.ext_programs);
   g_free (confile.crapbook_file);
   g_free (confile.snippets_dir);
   g_free (confile.bmx_file);
@@ -246,10 +274,10 @@ void confile_free (void)
   g_free (confile.sessions_dir);
   g_free (confile.tea_rc);
   g_free (confile.tea_ui);
-  g_free (confile.tea_gl_famous);
   g_free (confile.default_markup_mode);
   g_free (confile.autosave_file);
-
+  g_free (confile.crash_file);
+    
   g_free (confile.tea_recent);
   g_free (confile.tea_hotkeys);
 
@@ -258,29 +286,24 @@ void confile_free (void)
   g_free (confile.file_gtkrc);
 
   g_free (confile.cmd_def_doc_browser);
-  g_free (confile.cmd_Opera);
-  g_free (confile.cmd_Firefox);
-  g_free (confile.cmd_Mozilla);
-  g_free (confile.cmd_Konqueror);
-  g_free (confile.cmd_Galeon);
-  g_free (confile.cmd_Dillo);
-  g_free (confile.cmd_Links);
-  g_free (confile.cmd_ELinks);
-  g_free (confile.cmd_Lynx);
-  g_free (confile.cmd_Epiphany);
-  g_free (confile.cmd_Other);
   g_free (confile.color_cursor);
 
   g_free (confile.fmt_color_function);
+  g_free (confile.last_session);
+
 
   g_free (confile.text_foreground);
   g_free (confile.text_background);
   g_free (confile.text_sel_foreground);
   g_free (confile.text_sel_background);
   
+
   g_free (confile.tag_color_lm_error_fg);
   g_free (confile.tag_color_lm_error_bg);
-  
+
+  g_free (confile.tag_current_line_fg);
+  g_free (confile.tag_current_line_bg);
+
   g_free (confile.tag_comment);
   g_free (confile.tag_identifier);
   g_free (confile.tag_digit);
@@ -297,6 +320,9 @@ void confile_free (void)
   g_free (confile.tag_html_tag_font);
   g_free (confile.tag_preprocessor_font);
   g_free (confile.tag_type_font);
+  
+  g_free (confile.tag_color_paint_fg);
+  g_free (confile.tag_color_paint_bg);
 
   g_free (confile.editor_font);
   g_free (confile.rtf_enc);
@@ -514,25 +540,40 @@ void add_recent_internal (t_note_page *doc)
 
 void tea_start (void)
 {
+
+#ifdef CHAI_MODE
+
+  gnome_vfs_init ();
+
+#endif
+
+  b_exit_flag = FALSE;
   last_dir = NULL;
   enc_guess_value = NULL;
   sr_wnd = NULL;
-  ht_user_menu = NULL;
+  ht_ext_programs = NULL;
   ht_autoreplace = NULL;
   gl_autosave = NULL;
   gl_enc_choosed = NULL;
   ht_entities = NULL;
   mni_autocomp = NULL;
   dox = NULL;
+  gl_notetab_positions = NULL;
   bookmarks = NULL;
   confile.msg_counter = 0;
   confile.iconv_encs = NULL;
   confile.current_movie = NULL;
 
+  gl_notetab_positions = g_list_append (gl_notetab_positions, g_strdup (_("Left")));
+  gl_notetab_positions = g_list_append (gl_notetab_positions, g_strdup (_("Right")));
+  gl_notetab_positions = g_list_append (gl_notetab_positions, g_strdup (_("Top")));
+  gl_notetab_positions = g_list_append (gl_notetab_positions, g_strdup (_("Bottom")));
+
   tooltips = gtk_tooltips_new ();
   gtk_tooltips_enable (tooltips); 
   cur_settings.selected_enc = g_strdup (confile.default_charset);
   gl_enc_available = create_enc_list ();
+
   calendar_init ();
   image_browser_init ();
 }
@@ -544,6 +585,8 @@ void tea_done (void)
   t_note_page *page;
   mni_tabs = NULL;
 
+  b_exit_flag = TRUE;
+
   GList *p = g_list_first (dox);
   while (p)
         {
@@ -559,13 +602,12 @@ void tea_done (void)
   g_list_free (dox);
   glist_strings_free (recent_list);
   glist_strings_free (bookmarks);
+  glist_strings_free (gl_notetab_positions);
+  glist_strings_free (gl_image_formats);
 
   if (ht_tea_hotkeys)
      g_hash_table_destroy (ht_tea_hotkeys); 
 
-  if (ht_user_menu)
-     g_hash_table_destroy (ht_user_menu); 
-
   if (ht_entities)
      g_hash_table_destroy (ht_entities); 
 
@@ -590,6 +632,15 @@ void tea_done (void)
 
   if (last_dir)
      g_free (last_dir);
+
+#ifdef CHAI_MODE
+
+  g_free (source_languages_manager);
+  gnome_vfs_shutdown ();
+  done_hl ();
+
+#endif
+
 }
 
 
@@ -769,26 +820,6 @@ void put_tmp_file_string (const gchar *s)
 }
 */
 
-void reload_usermenu (void)
-{
-  if (! confile.user_menu_file)
-     return;
-
-  if (! g_file_test (confile.user_menu_file, G_FILE_TEST_EXISTS))
-     return;
-
-  if (ht_user_menu)
-     g_hash_table_destroy (ht_user_menu); 
-
-  ht_user_menu = load_file_to_hashtable (confile.user_menu_file);
- 
-  gtk_widget_destroy (mni_user_menu_menu);
-  mni_user_menu_menu = new_menu_submenu (mni_user_menu);
-  mni_temp = new_menu_tof (mni_user_menu_menu);
-
-  build_menu_from_ht (ht_user_menu, mni_user_menu_menu, on_mni_user_menu_item);
-}
-
 
 void fill_entities (void)
 {
@@ -804,15 +835,11 @@ void fill_entities (void)
   g_hash_table_insert (ht_entities, _("trade mark sign"), "8482");
   g_hash_table_insert (ht_entities, _("feminine ordinal indicator"), "170");
   g_hash_table_insert (ht_entities, _("left-pointing double angle quotation mark"), "171");
-//  g_hash_table_insert (ht_entities, _("not sign"), "172");
   g_hash_table_insert (ht_entities, _("soft hyphen"), "173");
   g_hash_table_insert (ht_entities, _("registered sign"), "174");
   g_hash_table_insert (ht_entities, _("degree sign"), "176");
   g_hash_table_insert (ht_entities, _("plus-minus sign"), "177");
   g_hash_table_insert (ht_entities, _("right-pointing double angle quotation mark"), "187");
-//  g_hash_table_insert (ht_entities, _("fraction one quarter"), "188");
-//  g_hash_table_insert (ht_entities, _("fraction one half"), "189");
-//  g_hash_table_insert (ht_entities, _("fraction three quarters"), "190");
   g_hash_table_insert (ht_entities, _("left single quotation mark"), "8216");
   g_hash_table_insert (ht_entities, _("right single quotation mark"), "8217");
   g_hash_table_insert (ht_entities, _("euro sign"), "8364");
@@ -832,6 +859,20 @@ void fill_entities (void)
   g_hash_table_insert (ht_entities, _("less-than sign"), "60");
   g_hash_table_insert (ht_entities, _("greater-than sign"), "62");
   g_hash_table_insert (ht_entities, _("apostrophe"), "39");
+
+  g_hash_table_insert (ht_entities, "\342\234\202", "9986");
+  g_hash_table_insert (ht_entities, "\342\235\200", "10048");
+  g_hash_table_insert (ht_entities, "\342\234\216", "9998");
+  g_hash_table_insert (ht_entities, "\342\230\240", "9760");
+  g_hash_table_insert (ht_entities, "\342\230\256", "9774");
+  
+  g_hash_table_insert (ht_entities, "\342\230\255", "9773");
+  g_hash_table_insert (ht_entities, "\342\230\242", "9762");
+  g_hash_table_insert (ht_entities, "\342\231\253", "9835");
+  
+  g_hash_table_insert (ht_entities, "\342\234\255", "10029");
+  g_hash_table_insert (ht_entities, "\342\230\235", "9757");
+  g_hash_table_insert (ht_entities, "\342\230\237", "9759");
 }
 
 
@@ -924,18 +965,18 @@ void confile_reload (void)
 {
   confile_free ();
 
-  confile.confdata = NULL;
-  
   confile.screen_w = gdk_screen_width ();
   confile.screen_h = gdk_screen_height ();
 
-  gchar *s = g_get_home_dir ();
-  
-  confile.tea_main_dir = g_strconcat (s, G_DIR_SEPARATOR_S, ".tea", NULL);
+  gchar *old_tea_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".tea", NULL);
+  gchar *conf_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".config", NULL);
+
+  confile.tea_main_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".config", G_DIR_SEPARATOR_S, "tea", NULL);
 
   confile.tmp_dir = g_strconcat (g_get_tmp_dir (), G_DIR_SEPARATOR_S, "teatmpdir", NULL);
   confile.tmp_file = g_strconcat (g_get_tmp_dir (), G_DIR_SEPARATOR_S, "tea_temp.html", NULL);
-  confile.user_menu_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_user_menu", NULL); 
+  confile.ext_programs = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "ext_programs", NULL); 
+
   confile.tea_autoreplace = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_autoreplace", NULL); 
   confile.bmx_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_bmx", NULL); 
   confile.sessions_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "sessions", G_DIR_SEPARATOR_S, NULL);
@@ -943,20 +984,34 @@ void confile_reload (void)
   confile.templates_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "templates", G_DIR_SEPARATOR_S, NULL);
   confile.crapbook_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "crapbook.txt", NULL);
   confile.file_gtkrc = get_tea_config_file ("gtkrc");
-  confile.dir_thumbs = g_strconcat (s, G_DIR_SEPARATOR_S, ".thumbnails", G_DIR_SEPARATOR_S, "normal", NULL);
+  confile.dir_thumbs = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".thumbnails", G_DIR_SEPARATOR_S, "normal", NULL);
 
+  confile.last_session = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "last_session", NULL); 
+ 
+  confile.crash_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "crash_file", NULL);
+  
   confile.autosave_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_autosave_list", NULL);
   confile.tea_rc = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_rc", NULL);
   confile.tea_ui = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_ui", NULL);
-  confile.tea_gl_famous = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_gl_famous", NULL);
-  confile.tea_kwas_history = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_kwas_history", NULL);
-  confile.tea_kwas_bookmarks = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_kwas_bookmarks", NULL);
+  confile.tea_kwas_bookmarks = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".gtk-bookmarks", NULL);
 
   confile.tea_recent = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_recent", NULL);
   confile.tea_hotkeys = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_hotkeys", NULL);
-  confile.tea_choosed_charsets = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_charsets", NULL);
+  confile.tea_choosed_charsets = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "charsets", NULL);
  
-  if (! g_file_test (confile.tea_main_dir, G_FILE_TEST_IS_DIR))
+
+  if (! g_file_test (conf_dir, G_FILE_TEST_EXISTS))
+     mkdir (conf_dir, S_IRUSR | S_IWUSR | S_IXUSR);
+
+  if (! g_file_test (confile.tea_rc, G_FILE_TEST_EXISTS))
+  if (g_file_test (old_tea_dir, G_FILE_TEST_EXISTS))
+    {
+     gchar *cm = g_strconcat ("mv ", old_tea_dir, " ", confile.tea_main_dir,  NULL);
+     system (cm);
+     g_free (cm);
+    }
+else
+//  if (! g_file_test (confile.tea_main_dir, G_FILE_TEST_EXISTS))
      {
       if (mkdir (confile.tea_main_dir, S_IRUSR | S_IWUSR | S_IXUSR) != -1) 
          { 
@@ -968,6 +1023,8 @@ void confile_reload (void)
          } 
      }
 
+  g_free (old_tea_dir);
+
   if (! g_file_test (confile.tea_rc, G_FILE_TEST_EXISTS))
       create_empty_file (confile.tea_rc, "#TEA editor configuration file. Please read the manual");
 
@@ -980,7 +1037,7 @@ void confile_reload (void)
   ht_config = NULL;
   ht_config = load_file_to_hashtable (confile.tea_rc);
 
-  gchar *x = g_strconcat (s, G_DIR_SEPARATOR_S, NULL);
+  gchar *x = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, NULL);
   confile.def_save_dir = ht_get_char_value ("def_save_dir", x);
   confile.def_open_dir = ht_get_char_value ("def_open_dir", x);
   g_free (x); 
@@ -991,33 +1048,65 @@ void confile_reload (void)
   confile.ext_pic_viewer = ht_get_char_value ("ext_pic_viewer", "display %s&");
   confile.date_time = ht_get_char_value ("date_time", "%d/%m/%Y %T");
   confile.max_recent_items = ht_get_int_value ("max_recent_items", 7);
-  confile.famous_history_max = (ht_get_int_value ("famous_history_max", 7) + 1);
+//  confile.famous_history_max = (ht_get_int_value ("famous_history_max", 7) + 1);
+
+  confile.fullscreen = ht_get_int_value ("fullscreen", FALSE);
+
+  confile.autosave_interval = ht_get_int_value ("autosave_interval", 3);
+
+  confile.do_save_all_on_termination = ht_get_int_value ("do_save_all_on_termination", 0);
+
+  confile.do_crash_file = ht_get_int_value ("do_crash_file", 0);
+  
+  confile.hl_current_line = ht_get_int_value ("hl_current_line", 0);
+  confile.det_charset_by_meta = ht_get_int_value ("det_charset_by_meta", 0);
 
   confile.now_playing = ht_get_char_value ("now_playing", "Now playing %s");
   confile.default_markup_mode = ht_get_char_value ("default_markup_mode", "HTML");
+  
   def_mm = get_markup_mode ();  
 
   confile.saveopen_h = ht_get_int_value ("saveopen_h", 75);
   confile.saveopen_w = ht_get_int_value ("saveopen_w", 75);
+  
+  confile.margin_width = ht_get_int_value ("margin_width", 72);
+  confile.margin_visible = ht_get_int_value ("margin_visible", 0);
+  
+
+  confile.notebook_tab_position = ht_get_int_value ("notebook_tab_position", GTK_POS_TOP);
+
+  confile.prompt_on_not_saved = ht_get_int_value ("prompt_on_not_saved", 1);
+  confile.prompt_on_file_exists = ht_get_int_value ("prompt_on_file_exists", 1);
+  confile.common_closing_button_visible = ht_get_int_value ("common_closing_button_visible", 1);
 
-  confile.prompt_on_not_saved = ht_get_int_value ("prompt_on_not_saved", 0);
-  confile.prompt_on_file_exists = ht_get_int_value ("prompt_on_file_exists", 0);
 
   confile.start_with_blank_file = ht_get_int_value ("start_with_blank_file", 0); 
-  confile.start_with_recent_file = ht_get_int_value ("start_with_recent_file", 0); 
 
+  confile.do_last_session = ht_get_int_value ("do_last_session", 0);
   confile.show_line_nums = ht_get_int_value ("show_line_nums", 0);
   confile.word_wrap = ht_get_int_value ("word_wrap", 1);
   confile.tab_size = ht_get_int_value ("tab_size", 3);
 
   confile.fmt_color_function = ht_get_char_value ("fmt_color_function", "<span style=\"color:@color;\">@text</span>");
 
+  
+  confile.def_file_ext = ht_get_char_value ("def_file_ext", "txt");
+  confile.add_def_file_ext = ht_get_int_value ("add_def_file_ext", 0);
+
+
   confile.text_foreground = ht_get_char_value ("text_foreground", "black");
   confile.text_background = ht_get_char_value ("text_background", "white");
   confile.text_sel_foreground = ht_get_char_value ("text_sel_foreground", "white");
   confile.text_sel_background = ht_get_char_value ("text_sel_background", "black");
 
-  confile.color_cursor = ht_get_char_value ("color_cursor", "red");
+  confile.tag_color_paint_fg = ht_get_char_value ("tag_color_paint_fg", "white");
+  confile.tag_color_paint_bg = ht_get_char_value ("tag_color_paint_bg", "red");
+
+  confile.tag_current_line_fg = ht_get_char_value ("tag_current_line_fg", "black");
+  confile.tag_current_line_bg = ht_get_char_value ("tag_current_line_bg", "#ffdcc3");
+
+
+  confile.color_cursor = ht_get_char_value ("color_cursor", "black");
   confile.tag_color_lm_error_fg = ht_get_char_value ("tag_color_lm_error_fg", "red");
   confile.tag_color_lm_error_bg = ht_get_char_value ("tag_color_lm_error_bg", confile.text_background);
   
@@ -1051,24 +1140,12 @@ void confile_reload (void)
   confile.cm_run_latex = ht_get_char_value ("cm_run_latex", "latex -file-line-error-style %s");
  
   //n.p. Scorn - Orgy Of Holyness
-
-  //some default values were taken from Bluefish
-
-  confile.cmd_Opera = ht_get_char_value ("opera","opera -remote 'openURL(%s,new-window)' || opera %s&");
-  confile.cmd_Firefox = ht_get_char_value ("firefox", "firefox %s&");
-  confile.cmd_Mozilla = ht_get_char_value ("mozilla", "mozilla -remote 'openURL(%s, new-window)' || mozilla %s&");
-  confile.cmd_Konqueror = ht_get_char_value ("konqueror", "konqueror %s&");
-  confile.cmd_Galeon = ht_get_char_value ("galeon", "galeon -x %s&");
-  confile.cmd_Dillo = ht_get_char_value ("dillo", "dillo %s&");
-  confile.cmd_Links = ht_get_char_value ("links", "konsole -e links %s&");
-  confile.cmd_ELinks = ht_get_char_value ("elinks", "konsole -e elinks %s&");
-  
-  confile.cmd_Lynx = ht_get_char_value ("lynx", "konsole -e lynx %s&");
-  confile.cmd_Epiphany = ht_get_char_value ("epiphany", "epiphany %s&");
-  confile.cmd_Other = ht_get_char_value ("other_browser", "%s&");
+ 
   confile.cmd_def_doc_browser = ht_get_char_value ("def_doc_browser", "mozilla %s&");
   confile.use_def_doc_browser = ht_get_int_value ("use_def_doc_browser", 0);
 
+  confile.allow_multiple_instances = ht_get_int_value ("allow_multiple_instances", 0);
+
   confile.use_cursor_blink = ht_get_int_value ("use_cursor_blink", 1);
   set_cursor_blink (confile.use_cursor_blink);
 
@@ -1094,6 +1171,9 @@ void confile_reload (void)
 
   confile.ins_spaces_on_tab_press = ht_get_int_value ("ins_spaces_on_tab_press", 0);
   confile.use_snippets = ht_get_int_value ("use_snippets", 1);
+
+  confile.do_autosave = ht_get_int_value ("do_autosave", 0);
+
   confile.use_def_save_dir = ht_get_int_value ("use_def_save_dir", 0);
   confile.use_def_open_dir = ht_get_int_value ("use_def_open_dir", 0);
 
@@ -1124,6 +1204,11 @@ void confile_reload (void)
   widget_apply_colors (ent_search);
   widget_apply_colors (tv_logmemo);
   
+  if (notebook1)
+     gtk_notebook_set_tab_pos (notebook1, confile.notebook_tab_position);
+ 
+  g_free (conf_dir);
+  
   get_iconv_sup ();
 }
 
@@ -1150,3 +1235,39 @@ void write_gtkrc (void)
   save_string_to_file (confile.file_gtkrc, s);
   g_free (s);
 }
+
+
+void reload_ext_programs (void)
+{
+  if (! confile.ext_programs)
+     return;
+
+  if (! g_file_test (confile.ext_programs, G_FILE_TEST_EXISTS))
+      {
+       GList *l = NULL;
+       l = g_list_prepend (l, "Opera=opera -remote 'openURL(%s,new-window)' || opera %s&");
+       l = g_list_prepend (l, "Firefox=firefox %s&");
+       l = g_list_prepend (l, "Mozilla=mozilla -remote 'openURL(%s, new-window)' || mozilla %s&");
+       l = g_list_prepend (l, "Konqueror=konqueror %s&");
+       l = g_list_prepend (l, "Galeon=galeon -x %s&");
+       l = g_list_prepend (l, "Dillo=dillo %s&");
+       l = g_list_prepend (l, "Links=konsole -e links %s&");
+       l = g_list_prepend (l, "Elinks=konsole -e elinks %s&");
+       l = g_list_prepend (l, "Lynx=konsole -e lynx %s&");
+       l = g_list_prepend (l, "Epiphany=epiphany %s&");
+  
+       glist_save_to_file (l, confile.ext_programs); 
+       g_list_free (l);
+      }
+
+  if (ht_ext_programs)
+     g_hash_table_destroy (ht_ext_programs); 
+  
+  ht_ext_programs = load_file_to_hashtable (confile.ext_programs);
+  
+  gtk_widget_destroy (mni_ext_programs_menu);
+  mni_ext_programs_menu = new_menu_submenu (mni_ext_programs);
+  mni_temp = new_menu_tof (mni_ext_programs_menu);
+
+  build_menu_from_ht (ht_ext_programs, mni_ext_programs_menu, on_mni_ext_programs_menu_item);
+}
