@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Dec 12 2003
     copyright            : (C) 2003, 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
  ***************************************************************************/
 
 /*
@@ -25,10 +25,13 @@ Copyright (C) 2000  Kh. Naba Kumar Singh
 #  include <config.h>
 #endif
 
+#include <unistd.h>
+
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib/gi18n.h>
 #include <errno.h>
 #include <sys/stat.h>
 #include <time.h>
@@ -211,90 +214,6 @@ gchar *most_efficient_filename(gchar *filename) {
 	return filename;
 }
 
-/**
- * create_relative_link_to:
- * @current_filepath: a #gchar * with the current filename
- * @link_to_filepath: a #gchar * with a file to link to
- *
- * creates a newly allocated relative link from current_filepath
- * to link_to_filepath
- *
- * if current_filepath == NULL it returns the most efficient filepath
- * for link_to_filepath
- *
- * if link_to_filepath == NULL it will return NULL
- *
- * Return value: a newly allocated gchar * with the relative link
- **/
-gchar *create_relative_link_to(gchar * current_filepath, gchar * link_to_filepath)
-{
-	gchar *returnstring = NULL;
-	gchar *eff_current_filepath, *eff_link_to_filepath;
-	gint common_lenght, maxcommonlen;
-	gint current_filename_length, link_to_filename_length, current_dirname_length, link_to_dirname_length;
-	gint count, deeper_dirs;
-
-	if (!current_filepath){
-		returnstring = most_efficient_filename(g_strdup(link_to_filepath));
-		return returnstring;
-	}
-	if (!link_to_filepath) {
-		return NULL;
-	}
-	eff_current_filepath = most_efficient_filename(g_strdup(current_filepath));
-	eff_link_to_filepath = most_efficient_filename(g_strdup(link_to_filepath));
-	/* get the size of the directory of the current_filename */
-	current_filename_length = strlen(strrchr(eff_current_filepath, G_DIR_SEPARATOR))-1;
-	link_to_filename_length = strlen(strrchr(eff_link_to_filepath, G_DIR_SEPARATOR))-1;
-	current_dirname_length = strlen(eff_current_filepath) - current_filename_length;
-	link_to_dirname_length = strlen(eff_link_to_filepath) - link_to_filename_length;
-
-	if (current_dirname_length < link_to_dirname_length) {
-		maxcommonlen = current_dirname_length;
-	} else {
-		maxcommonlen = link_to_dirname_length;
-	}
-
-	/* first lets get the common basedir for both dir+file  by comparing the
-	   common path in the directories */
-	common_lenght = 0;
-	while ((strncmp(eff_current_filepath, eff_link_to_filepath, common_lenght + 1)) == 0) {
-		common_lenght++;
-		if (common_lenght >= maxcommonlen) {
-			common_lenght = maxcommonlen;
-			break;
-		}
-	}
-	/* this is the common length, but we need the common directories */
-	if (eff_current_filepath[common_lenght] != G_DIR_SEPARATOR) {
-		gchar *ltmp = &eff_current_filepath[common_lenght];
-		while ((*ltmp != G_DIR_SEPARATOR) && (common_lenght > 0)) {
-			common_lenght--;
-			ltmp--;
-		}
-	}
-
-	/* now we need to count how much deeper (in directories) the current_filename
-	   is compared to the link_to_file, that is the amount of ../ we need to add */
-	deeper_dirs = 0;
-	for (count = common_lenght+1; count <= current_dirname_length; count++) {
-		if (eff_current_filepath[count] == G_DIR_SEPARATOR) {
-			deeper_dirs++;
-		}
-	}
-
-	/* now we know everything we need to know we can create the relative link */
-	returnstring = g_malloc0((strlen(link_to_filepath) - common_lenght + 3 * deeper_dirs + 1) * sizeof(gchar *));
-	count = deeper_dirs;
-	while (count) {
-		strcat(returnstring, "../");
-		count--;
-	}
-	strcat(returnstring, &eff_link_to_filepath[common_lenght+1]);
-	g_free(eff_current_filepath);
-	g_free(eff_link_to_filepath);
-	return returnstring;
-}
 
 /**
  * create_full_path:
@@ -435,12 +354,12 @@ void handle_file_enc (gchar *filename, gchar *enc)
   open_file_std (filename);
 }
       
-
-gboolean is_image (const gchar *filename)
+/*
+gboolean is_image2 (const gchar *filename)
 {
   return is_ext (filename, ".png", ".gif", ".jpg", ".jpeg", ".wbmp", ".bmp", ".mng", NULL);
 }
-
+*/
 
 gboolean is_tex (const gchar *filename)
 {
@@ -476,6 +395,23 @@ gint get_file_size (const gchar *filename)
 }
 
 
+gboolean check_ext_wo_dot (gchar *filename, gchar *ext)
+{
+  if (! filename || ! ext)
+     return FALSE;
+
+  gboolean r = FALSE;
+  gchar *f = g_utf8_strdown (filename, -1);
+
+  gchar *full_ext = g_strconcat (".", ext, NULL);
+
+  r = g_str_has_suffix (f, full_ext);
+  g_free (full_ext);
+  g_free (f);
+  return r; 
+}
+
+
 gboolean check_ext (gchar *filename, gchar *ext)
 {
   if (! filename || ! ext)
@@ -790,6 +726,8 @@ gchar* find_good_browser (void)
             t = g_find_program_in_path ("mozilla");
             if (! t)
                 t = g_find_program_in_path ("galeon");
+                   if (! t)
+                      t = g_find_program_in_path ("yelp");
 
    return t;
 }
@@ -885,65 +823,57 @@ void insert_image (gchar *a_filename)
   if (! g_file_test (a_filename, G_FILE_TEST_EXISTS))
      return;
 
-  gint *width;
-  gint *height;
+  gint width = 0;
+  gint height = 0;
   gdk_pixbuf_get_file_info (a_filename, &width, &height);
 
-  gchar *dir = g_path_get_dirname (cur_text_doc->file_name_local);
-  gchar *filename = create_relative_link_to (dir, a_filename);
- 
+  gchar *filename = create_relative_link (cur_text_doc->file_name_local, a_filename);
+
+
   if (! filename) 
      {
-      g_free (dir); 
       return;
      }
 
   gint mm = get_markup_mode ();       
   gchar *t;
 
-  gchar *x = g_strrstr (filename, G_DIR_SEPARATOR_S);
-  if (x)
-     t = g_utf8_next_char (x);
-  else
-      t = filename; 
-
   gchar *temp = g_malloc (7777);
 
   if (mm == MM_HTML) 
       g_snprintf (temp,
                   7777,
                   "<img src=\"%s\" border=\"0\" alt=\"\" width=\"%d\" height=\"%d\">",
-                  t, width, height);
+                  filename, width, height);
   else
   if (mm == MM_XHTML) 
      g_snprintf (temp,
                  7777,
                  "<img src=\"%s\" border=\"0\" alt=\"\" width=\"%d\" height=\"%d\" />",
-                 t, width, height);
+                 filename, width, height);
   else
       if (mm == MM_DOCBOOK) 
           g_snprintf (temp,
                       7777,
                       "<mediaobject><imageobject>\n<imagedata fileref=\"%s\"/>\n</imageobject></mediaobject>",
-                      t);
+                      filename);
   else
   if (mm == MM_WIKI) 
      g_snprintf (temp,
                  7777,
                  "[[Image:%s|thumb|alternative text]]",
-                 t);
+                 filename);
   else
   if (mm == MM_TEX) 
      g_snprintf (temp,
                  7777,
                  "\\includegraphics{%s}",
-                 t);
+                 filename);
     
   doc_insert_at_cursor (cur_text_doc, temp);
 
   g_free (temp);
   g_free (filename);
-  g_free (dir);
 }
 
 
@@ -955,70 +885,23 @@ void insert_link (gchar *a_filename)
   if (! g_file_test (a_filename, G_FILE_TEST_EXISTS))
      return;
   
-  gchar *dir = g_path_get_dirname (cur_text_doc->file_name_local);
-  gchar *filename = create_relative_link_to (dir, a_filename);
+  gchar *filename = create_relative_link (cur_text_doc->file_name_local, a_filename);
  
   if (! filename) 
      {
-      g_free (dir); 
       return;
      }
        
-  gchar *t;
-  gchar *x = g_strrstr (filename, G_DIR_SEPARATOR_S);
-  if (x)
-     t = g_utf8_next_char (x);
-  else
-      t = filename; 
-
-  gchar *z =  g_strdup_printf ("<a href=\"%s\"></a>", t); 
+  gchar *z =  g_strdup_printf ("<a href=\"%s\"></a>", filename); 
 
   doc_insert_at_cursor (cur_text_doc, z);
   doc_move_cursor_backw_middle_tags (cur_text_doc);
 
   g_free (filename);
-  g_free (dir);
   g_free (z);
 }
 
 
-static build_menu_from_ht_cb (gpointer key,
-                              gpointer value,
-                              gpointer user_data)
-{
-  t_ppair *t = user_data;
-  new_menu_item (key, t->a, t->b);
-}
-
-
-void build_menu_from_ht (GHashTable *hash_table, gpointer menu, gpointer callback)
-{
-   if (! ht_entities)
-       return; 
- 
-   t_ppair t;
-   t.a = menu;
-   t.b = callback; 
-
-   g_hash_table_foreach (hash_table,
-                         build_menu_from_ht_cb,
-                         &t);
-}
-
-
-void build_menu_from_glist (GList *list, gpointer menu, gpointer callback)
-{
-   if (! list)
-       return; 
- 
-   GList *p = g_list_first (list);
-   while (p)
-        {
-         if (strlen (p->data) >= 1)
-            mni_temp = new_menu_item (p->data, menu, callback);
-         p = g_list_next (p);
-        }
-}
 
 
 void handle_file_ide (gchar *filename, gint line)
@@ -1128,8 +1011,8 @@ GList* read_dir_files (gchar *path)
 }
 
 /*
-static gint get_markup_mode (void)
-returns an ID of markup mode
+gint get_markup_mode (void)
+returns an ID of the markup mode
 */
 gint get_markup_mode (void)
 {
@@ -1163,7 +1046,7 @@ gchar* get_amarok_now_playing (void)
 
   gchar *x = locale_to_utf8 (standard_output);
   g_free (standard_output);
-  return x;
+  return g_strstrip (x);
 }
 
 
@@ -1244,10 +1127,177 @@ gchar* correct_relative_filename (const gchar *path, const gchar *filename)
 
 gchar* filename_from_xuri (const gchar *uri)
 {
-  gchar *p = strstr (uri, "file:/");
-  if (! p)
+  gchar *p = NULL;
+  gint mode = 0;
+
+  /*
+  0 - no uri
+  1 - file:/
+  2 - file:///
+  */
+
+  p = strstr (uri, "file:///");
+  if (p)
+     mode = 2;
+  else
+      {
+       p = strstr (uri, "file:/");
+       if (p)
+          mode = 1;
+      }
+
+  if (mode == 0)
      return g_strdup (uri);
 
-  p+=5;
+  if (mode == 1) 
+     p+=5;
+  else
+      p+=7;
+ 
   return g_strdup (p);
-}
\ No newline at end of file
+}
+
+
+gchar *create_relative_link (const gchar *doc_filename, const gchar *img_filename)
+{
+  gchar *dir_doc_filename = g_path_get_dirname (doc_filename);
+  gchar *dir_img_filename = g_path_get_dirname (img_filename);
+  
+  gint dir_doc_filename_len = strlen (dir_doc_filename);
+  gint dir_img_filename_len = strlen (dir_img_filename);;
+
+  //if the directories are the same, return the pure filename
+  
+  if (strcmp (dir_doc_filename, dir_img_filename) == 0)
+     {
+      g_free (dir_doc_filename); 
+      g_free (dir_img_filename);
+      return g_path_get_basename (img_filename);
+     } 
+
+  //if img_filename is in the upper dir than doc_filename, we return the pure filename 
+  if (strcmp (dir_img_filename, dir_doc_filename) < 0)
+     {
+      g_free (dir_doc_filename); 
+      g_free (dir_img_filename);
+      return g_path_get_basename (img_filename);
+     } 
+
+  //if img_filename is in the lower dir than doc_filename, we return the relative filename 
+  if (strcmp (dir_doc_filename, dir_img_filename) < 0)
+  if (strstr (dir_img_filename, dir_doc_filename))
+     {
+      
+      gchar *rel_path = dir_img_filename + dir_doc_filename_len;      
+      gchar *pure_filename = g_path_get_basename (img_filename);
+      gchar *x = g_strconcat (".", rel_path, "/", pure_filename, NULL);
+      g_free (pure_filename);
+      g_free (dir_doc_filename); 
+      g_free (dir_img_filename);
+
+      return g_strdup (x);
+     }
+
+   return g_path_get_basename (img_filename);
+}
+
+///////////////////////WRITE ME
+gchar* create_full_path2 (gchar *filename, gchar *basedir) 
+{
+
+}
+//////////////////////
+
+
+gboolean is_ext_arr (gchar *filename, gchar *exts)
+{
+  if (! filename || ! exts)
+     return FALSE;
+ 
+  gboolean r = FALSE;
+
+  gchar **arr = g_strsplit (exts, ";", -1);
+
+  if (! arr)
+     return FALSE;
+
+  gint c = -1;
+
+  while (arr[c++])
+      {
+       r = check_ext_wo_dot (filename, arr [c]);
+       if (r)
+          break;
+      }
+            
+  g_strfreev (arr);
+
+  return r;
+}
+
+
+void add_image_format (GdkPixbufFormat *data, GList **list)
+{
+  gchar** arr = gdk_pixbuf_format_get_extensions (data); 
+  if (! arr)
+     return;
+ 
+  gchar *extensions = g_strjoinv (";", arr);
+  *list = g_list_prepend (*list, extensions);
+  g_strfreev (arr);
+}
+
+
+GList* image_formats_fill (void)
+{
+  GSList *sl_formats = gdk_pixbuf_get_formats ();
+  GList *result = NULL;
+  g_slist_foreach (sl_formats, add_image_format, &result);
+  g_slist_free (sl_formats);
+  return result;
+}
+
+
+gboolean is_image (const gchar *filename)
+{
+  if (! gl_image_formats)
+     return FALSE;
+
+  gboolean r = FALSE;
+
+  GList *t = g_list_first (gl_image_formats);
+  while (t)
+        {
+         r = is_ext_arr (filename, t->data);
+         if (r)
+             break;           
+
+         t = g_list_next (t);
+        }
+
+  return r;
+}
+
+
+gboolean is_writable (gchar *filename)
+{
+  if (access (filename, W_OK) != 0)
+     return FALSE;
+  else
+      return TRUE;
+}
+
+
+gboolean is_readable (gchar *filename)
+{
+  if (access (filename, R_OK) != 0)
+     return FALSE;
+  else
+      return TRUE;
+}
+
+
+gboolean has_ext (gchar *filename)
+{
+  return (strstr (++filename, "."));
+}
