@@ -3,7 +3,7 @@
                              -------------------
     begin                : aug. 2004
     copyright            : (C) 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
  ***************************************************************************/
 //  Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
 //  Copyright (C) 2000, 2002 Chema Celorio, Paolo Maggi
@@ -25,7 +25,7 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <gdk/gdkkeysyms.h>
-
+#include <glib/gi18n.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -44,6 +44,10 @@ GtkWidget* tea_text_entry (GtkWidget *container, gchar *caption, gchar *value)
   gtk_box_pack_start (container, b, FALSE, TRUE, UI_PACKFACTOR);
  
   GtkWidget *x = gtk_label_new (caption);  
+  //gtk_label_set_markup (x, value); 
+  gtk_label_set_use_markup (x, TRUE); 
+
+
   gtk_widget_show (x);
   gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
   x = gtk_entry_new ();   
@@ -52,7 +56,7 @@ GtkWidget* tea_text_entry (GtkWidget *container, gchar *caption, gchar *value)
 
   if (value)
      gtk_entry_set_text (x, value);
-
+    
   return x;
 }
 
@@ -204,6 +208,29 @@ GtkWidget* tea_dir_selector (GtkWidget *container, gchar *caption, gchar *value)
 }
 
 
+//returns combo
+GtkWidget* tea_combo_combo (GtkWidget *container, GList *strings, gchar *caption, gint value)
+{
+  GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (b);
+  gtk_box_pack_start (container, b, FALSE, TRUE, UI_PACKFACTOR);
+ 
+  GtkWidget *x = gtk_label_new (caption);  
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
+  x = gtk_combo_box_new_text ();   
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, TRUE, TRUE, UI_PACKFACTOR);
+
+  if (strings)
+    fill_combo_with_glist (x, strings);
+  
+   gtk_combo_box_set_active (x, value);
+
+  return x;
+}
+
+
 GtkWidget* tea_combo (GtkWidget *container, GList *strings, gchar *caption, gchar *value)
 {
   GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
@@ -219,7 +246,7 @@ GtkWidget* tea_combo (GtkWidget *container, GList *strings, gchar *caption, gcha
 
   if (strings)
     fill_combo_with_glist (x, strings);
-  
+
   GtkEntry *e = GTK_ENTRY (GTK_BIN (x)->child);
 
   if (value)
@@ -540,6 +567,16 @@ gboolean win_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w)
 }
 
 
+gboolean dlg_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w) 
+{
+  if (event->keyval == GDK_Escape)
+    {
+     gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_REJECT);   
+     return TRUE;
+    }
+  return FALSE;
+}
+
 //from Bluefish:: bf_lib.c and gtk_easy
 /**
  * window_destroy:
@@ -581,10 +618,13 @@ GtkWidget* tea_gtk_toolbar_prepend_space (GtkToolbar *toolbar)
 
 void fill_combo_with_glist (GtkComboBox *combo, GList *l)
 {
+  if (! combo || ! l)
+     return;
+
   GList *t = g_list_first (l);
   while (t && t->data)
         {
-         if (strlen (t->data) > 1) 
+         //if (strlen (t->data) > 1) 
             gtk_combo_box_append_text (combo, t->data);
          t = g_list_next (t); 
         }   
@@ -611,6 +651,27 @@ GtkWidget* tea_font_button (GtkWidget *container, gchar *caption, gchar *value)
   return x;
 }
 
+/*
+GtkWidget* tea_font_button (GtkWidget *container, gchar *caption, gchar *value)
+{
+  GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (b);
+  gtk_box_pack_start (container, b, FALSE, FALSE, UI_PACKFACTOR);
+
+  GtkWidget *x = gtk_label_new (caption);  
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
+
+  x = gtk_font_button_new ();   
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
+
+  if (value)
+     gtk_font_button_set_font_name (x, value);
+
+  return x;
+}
+*/
 
 GtkWidget* tea_stock_button (const gchar *stock_id)
 {
@@ -620,3 +681,115 @@ GtkWidget* tea_stock_button (const gchar *stock_id)
   gtk_widget_show_all (x);
   return x;
 }
+
+
+gchar* dlg_question_char (gchar *prompt, gchar *defval)
+{
+  gchar *result = NULL;  
+  GtkWidget *dialog = gtk_dialog_new_with_buttons (NULL, 
+                                                   NULL,
+                                                   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                   GTK_STOCK_CANCEL,
+                                                   GTK_RESPONSE_REJECT, 
+                                                   GTK_STOCK_OK,
+                                                   GTK_RESPONSE_ACCEPT,
+                                                   NULL);
+   
+  GtkWidget *hbox = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+
+  GtkWidget *im = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
+  gtk_container_add (GTK_DIALOG (dialog)->vbox, im);
+  gtk_widget_show (im);
+  
+  GtkWidget *ent = tea_text_entry (GTK_DIALOG (dialog)->vbox, prompt, defval);
+
+  if (gtk_dialog_run (dialog) == GTK_RESPONSE_ACCEPT)
+  if (gtk_entry_get_text (ent))
+      result = g_strdup (gtk_entry_get_text (ent));
+   
+  gtk_widget_destroy (dialog);
+  
+  return result;
+}
+
+
+static build_menu_from_ht_cb (gpointer key,
+                              gpointer value,
+                              gpointer user_data)
+{
+  t_ppair *t = user_data;
+  new_menu_item (key, t->a, t->b);
+}
+
+
+void build_menu_from_ht (GHashTable *hash_table, gpointer menu, gpointer callback)
+{
+   if (! ht_entities && ! hash_table)
+       return; 
+ 
+   t_ppair t;
+   t.a = menu;
+   t.b = callback; 
+
+   g_hash_table_foreach (hash_table,
+                         build_menu_from_ht_cb,
+                         &t);
+}
+
+
+void build_menu_from_glist (GList *list, gpointer menu, gpointer callback)
+{
+   if (! list)
+       return; 
+ 
+   GList *p = g_list_first (list);
+   while (p)
+        {
+         if (strlen (p->data) >= 1)
+            mni_temp = new_menu_item (p->data, menu, callback);
+         p = g_list_next (p);
+        }
+}
+
+
+//current music: Radiohead - OK Computer - Paranoid Andriod
+void build_menu_wudata_from_glist (GList *list, gpointer menu, gpointer callback, gpointer udata)
+{
+  if (! list)
+     return; 
+  GList *p = g_list_first (list);
+  while (p)
+       {
+        if (p->data)
+        if (strlen (p->data) >= 1)
+           mni_temp = new_menu_item_with_udata (p->data, menu, callback, udata);
+        p = g_list_next (p);
+       }
+}
+
+
+void tea_widget_show (GtkWidget *w, gboolean visible)
+{
+  if (visible)
+     gtk_widget_show (w);
+   else 
+       gtk_widget_hide (w);
+}
+
+
+GtkWidget* tea_color_selector_simple (GtkWidget *container, gchar *caption)
+{
+  GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (b);
+  gtk_box_pack_start (container, b, FALSE, TRUE, UI_PACKFACTOR);
+
+  GtkWidget *x = gtk_label_new (caption);  
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
+
+  GtkWidget *bt = gtk_color_button_new ();
+  gtk_widget_show (bt);
+  gtk_box_pack_start (b, bt, FALSE, FALSE, UI_PACKFACTOR);
+  
+  return bt;
+}
