@@ -3,7 +3,7 @@
                              -------------------
     begin                : 11.06.2004 - it was a really good day
     copyright            : (C) 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
  ***************************************************************************/
 /*
 portions of code from:
@@ -34,7 +34,7 @@ portions of code from:
 #include <unistd.h>
 #include <sys/stat.h>
 #include <gdk/gdkkeysyms.h>
-
+#include <glib/gi18n.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -97,12 +97,21 @@ static void kwas_navigate (t_kwas_win *w, gchar *path)
 {
   if (w->focused_panel)
      { 
+      gchar *dir = filename_from_xuri (path);
       g_free (w->focused_panel->path);
-      w->focused_panel->path = g_strdup (path); 
-      fill_filelist (w->focused_panel, path);
+      w->focused_panel->path = dir; 
+      fill_filelist (w->focused_panel, dir);
      } 
 }
 
+/*
+static void on_mni_kwas_cin_filelist (GtkButton *button,
+                                       gpointer user_data)
+{
+  t_kwas_win *w = user_data;
+  cinelerra_gen_filelins_dialog (w->focused_panel->path);
+}
+*/
 
 static void on_mni_kwas_imageplane (GtkButton *button,
                                     gpointer user_data)
@@ -132,6 +141,9 @@ static void kwas_bookmarks_menu_update (t_kwas_win *w)
   if (! gl_tea_kwas_bookmarks)
      return;
  
+  glist_strings_free (gl_tea_kwas_bookmarks);
+  gl_tea_kwas_bookmarks = load_file_to_glist (confile.tea_kwas_bookmarks);
+
   gtk_widget_destroy (w->mni_bookmarks_menu);
   w->mni_bookmarks_menu = new_menu_submenu (w->mni_bookmarks);
 
@@ -261,7 +273,11 @@ static void on_mni_kwas_add_bookmark (GtkMenuItem *menuitem,
                                       gpointer user_data)
 {
   t_kwas_win *w = user_data;
-  gl_tea_kwas_bookmarks = g_list_prepend (gl_tea_kwas_bookmarks, g_strdup (w->focused_panel->path));
+  gchar *dir = g_strconcat ("file:///", w->focused_panel->path, NULL);
+  gl_tea_kwas_bookmarks = g_list_prepend (gl_tea_kwas_bookmarks, dir);
+  glist_save_to_file (gl_tea_kwas_bookmarks, confile.tea_kwas_bookmarks);
+  glist_strings_free (gl_tea_kwas_bookmarks);
+  gl_tea_kwas_bookmarks = load_file_to_glist (confile.tea_kwas_bookmarks);
   kwas_bookmarks_menu_update (w);
 }
 
@@ -617,10 +633,7 @@ static void handle_enter (t_kwas_panel *p, gchar *f)
   if (S_ISREG (ti->fstat->st_mode))
      { 
       g_free (cur_settings.selected_enc);
-      //cur_settings.selected_enc = g_strdup (gtk_entry_get_text (w->enc_combo->entry));
-      //g_print ("%d\n", gtk_combo_box_get_active (w->cb_charset)); 
       cur_settings.selected_enc = g_strdup (g_list_nth_data (confile.iconv_encs, gtk_combo_box_get_active (w->cb_charset)));
-      //dbm (cur_settings.selected_enc);
       handle_file (ti->path, 0, TRUE);
       return;
      }
@@ -968,7 +981,10 @@ t_kwas_win* create_kwas_window (void)
 
   mni_temp = new_menu_item_with_udata (_("Run with..."), kwas_mn_functions, on_mni_kwas_run_with, w);
   mni_temp = new_menu_item_with_udata (_("Copy current file name"), kwas_mn_functions, on_mni_kwas_copy_filename, w);
-  mni_temp = new_menu_item_with_udata (_("Bookmark the current dir"), kwas_mn_functions, on_mni_kwas_add_bookmark, w);
+//  mni_temp = new_menu_item_with_udata (_("Bookmark the current dir"), kwas_mn_functions, on_mni_kwas_add_bookmark, w);
+//  mni_temp = new_menu_item_with_udata (_("Generate the file list for Cinelerra"), kwas_mn_functions, on_mni_kwas_cin_filelist, w);
+
+
 
   mni_temp = new_menu_item (_("Navigate"), mn_kwas_menu, NULL);
   mn_kwas_nav_menu = new_menu_submenu (mni_temp);
@@ -1046,25 +1062,10 @@ t_kwas_win* create_kwas_window (void)
   gtk_widget_show (hbox1);
   gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, TRUE, UI_PACKFACTOR);
 
-/*
-  w->cm_combo = gtk_combo_new ();
-  gtk_widget_show (w->cm_combo);
-  gtk_box_pack_start (GTK_BOX (hbox1), w->cm_combo, TRUE, TRUE, UI_PACKFACTOR);
-
-  w->cm_entry = GTK_COMBO (w->cm_combo)->entry;
-*/
-/*
-  w->cb_combo = gtk_combo_box_entry_new_text ();
-  gtk_widget_show (w->cb_combo);
-  gtk_box_pack_start (GTK_BOX (hbox1), w->cb_combo, TRUE, TRUE, UI_PACKFACTOR);
-
-  w->cm_entry = GTK_ENTRY (GTK_BIN (w->cb_combo)->child);
-*/
   w->cm_entry = gtk_entry_new ();
   gtk_widget_show (w->cm_entry);
   gtk_box_pack_start (GTK_BOX (hbox1), w->cm_entry, TRUE, TRUE, UI_PACKFACTOR);
 
-  //bt_go = gtk_button_new_with_mnemonic (_("Execute"));
   bt_go = gtk_button_new_from_stock (GTK_STOCK_EXECUTE);
   gtk_widget_show (bt_go);
   gtk_box_pack_start (GTK_BOX (hbox1), bt_go, FALSE, FALSE, UI_PACKFACTOR);
