@@ -1,9 +1,9 @@
 /***************************************************************************
-                          tea_gtk_utils.c  -  description
+                          tea_options.c  -  description
                              -------------------
     begin                : aug. 2004
     copyright            : (C) 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
  ***************************************************************************/
 
 /***************************************************************************
@@ -25,30 +25,281 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <gdk/gdkkeysyms.h>
-
+#include <glib/gi18n.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 
+#ifdef CHAI_MODE
+
+#include <gtksourceview/gtksourcetag.h>
+#include <gtksourceview/gtksourcelanguagesmanager.h>
+#include <gtksourceview/gtksourcetagtable.h>
+#include <gtksourceview/gtksourcetag.h>
+#include <gtksourceview/gtksourceview.h>
+
+#endif
+
+
 #include "tea_defs.h"
 #include "tea_options.h"
 #include "tea_gtk_utils.h"
 #include "tea_config.h"
+#include "tea_text_document.h"
+
+
+
+
+#ifdef CHAI_MODE
+
+
+static GtkSourceTagStyle *cur_tag_style;
+static GtkSourceTag *cur_tag;
+GtkSourceLanguage *cur_language;
+static GSList *avail_langs;
+
+
+static void update_cboxes_with_style (GtkSourceTagStyle *style)
+{
+  if (! style)
+     return;
+
+  gtk_toggle_button_set_active (cb_hl_italic, style->italic);
+  gtk_toggle_button_set_active (cb_hl_bold, style->bold);
+  gtk_toggle_button_set_active (cb_hl_underline, style->underline);
+  gtk_toggle_button_set_active (cb_hl_strikethrough, style->strikethrough);
+}
+
+
+static void cb_tv_available_hlangs_change (GtkComboBox *combobox,
+                                           gpointer user_data)
+{
+  if (! tv_hlang_elements)
+     return;
+
+  gint index = gtk_combo_box_get_active (combobox);
+  if (index == -1)
+     return;
+    
+  GSList *list = g_slist_nth (avail_langs, index);
+  if (! list)
+    return;  
+
+  cur_language = list->data;
+
+ // dbm (gtk_source_language_get_name (cur_language));
+ 
+  gchar *name;
+
+  if (gsl_tags_list)
+     {
+      g_slist_foreach (gsl_tags_list, (GFunc)g_object_unref, NULL);
+      g_slist_free (gsl_tags_list);
+     }
+  
+  gsl_tags_list = gtk_source_language_get_tags (GTK_SOURCE_LANGUAGE (cur_language));
+
+  cur_tag = gsl_tags_list->data;
+  GSList *gsl = gsl_tags_list;
+
+  glist_strings_free (gl_tags_list);
+  gl_tags_list = NULL;
+
+  while (gsl)
+        {
+         g_object_get (gsl->data, "name", &name, NULL);
+         gl_tags_list = g_list_append (gl_tags_list, name);
+         gsl = g_slist_next (gsl);
+        } 
+
+  gtk_list_store_clear (gtk_combo_box_get_model (tv_hlang_elements));
+  fill_combo_with_glist (tv_hlang_elements, gl_tags_list);
+
+  gtk_combo_box_set_active (tv_hlang_elements, 0);
+}
+
+
+static void cb_tv_hlang_elements_change (GtkComboBox *combobox,
+                                         gpointer user_data)
+{
+  if (! gsl_tags_list)
+     return;
+
+  gint index = gtk_combo_box_get_active (combobox);
+  if (index == -1)
+     return;
+
+  GSList *list = g_slist_nth (gsl_tags_list, index);
+  if (! list)
+     return;
+
+  if (cur_tag_style)
+     gtk_source_tag_style_free (cur_tag_style);
+
+  cur_tag = list->data;
+
+  cur_tag_style = gtk_source_tag_get_style (cur_tag);
+
+  gtk_color_button_set_color (bt_tag_foreground, &cur_tag_style->foreground);
+
+  update_cboxes_with_style (cur_tag_style);
+}
+
+
+static void cb_select_tag_color (GtkColorButton *widget, gpointer user_data) 
+{
+  GdkColor color;
+  gtk_color_button_get_color (widget, &color);  
+  cur_tag_style->foreground = color;
+
+  gchar *id;   
+  g_object_get (cur_tag, "id", &id, NULL);
+
+  gtk_source_language_set_tag_style (cur_language, id, cur_tag_style);
+  g_free (id);
+
+  save_tag (cur_language, cur_tag);
+}
+
+
+static void cb_hl_italic_toggle (GtkToggleButton *togglebutton, gpointer user_data)
+{
+  cur_tag_style->italic = gtk_toggle_button_get_active (togglebutton);
+  
+  gchar *id;   
+  g_object_get (cur_tag, "id", &id, NULL);
+
+  gtk_source_language_set_tag_style (cur_language, id, cur_tag_style);
+  g_free (id);
+
+  save_tag (cur_language, cur_tag);
+}
+
+
+static void cb_hl_bold_toggle (GtkToggleButton *togglebutton, gpointer user_data)
+{
+  cur_tag_style->bold = gtk_toggle_button_get_active (togglebutton);
+  
+  gchar *id;   
+  g_object_get (cur_tag, "id", &id, NULL);
+
+  gtk_source_language_set_tag_style (cur_language, id, cur_tag_style);
+  g_free (id);
+
+  save_tag (cur_language, cur_tag);
+}
+
+
+static void cb_hl_underline_toggle (GtkToggleButton *togglebutton, gpointer user_data)
+{
+  cur_tag_style->underline = gtk_toggle_button_get_active (togglebutton);
+
+  gchar *id;   
+  g_object_get (cur_tag, "id", &id, NULL);
+
+  gtk_source_language_set_tag_style (cur_language, id, cur_tag_style);
+  g_free (id);
+
+  save_tag (cur_language, cur_tag);
+}
+
+
+static void cb_hl_strikethrough_toggle (GtkToggleButton *togglebutton, gpointer user_data)
+{
+  cur_tag_style->strikethrough = gtk_toggle_button_get_active (togglebutton);
+  gtk_source_tag_set_style (cur_tag, cur_tag_style);
+
+  gchar *id;   
+  g_object_get (cur_tag, "id", &id, NULL);
+
+  gtk_source_language_set_tag_style (cur_language, id, cur_tag_style);
+  g_free (id);
+
+  save_tag (cur_language, cur_tag);
+}
+
+
+
+static GtkWidget* wnd_options_hl_chai (void)
+{
+  avail_langs = gtk_source_languages_manager_get_available_languages (source_languages_manager);
+  
+  cur_tag = NULL;
+  gsl_tags_list = NULL;
+  gl_tags_list = NULL;
+  cur_tag_style = NULL;
+  cur_language = NULL;
+
+  GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (page);
+
+  GtkWidget *hb = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  
+  gtk_widget_show (hb);
+  gtk_box_pack_start (page, hb, FALSE, FALSE, UI_PACKFACTOR);
+
+
+  tv_available_hlangs = tea_combo_combo (page, gl_supported_hlangs, _("Available highlighting modes"), 0); 
+  
+  g_signal_connect ((gpointer) tv_available_hlangs, "changed",
+                    G_CALLBACK (cb_tv_available_hlangs_change),
+                    NULL);
+
+
+  tv_hlang_elements = tea_combo_combo (page, NULL, _("Elements"), 0); 
+  g_signal_connect ((gpointer) tv_hlang_elements, "changed",
+                    G_CALLBACK (cb_tv_hlang_elements_change),
+                    NULL);
+  
+
+  bt_tag_foreground = tea_color_selector_simple (page, _("Element foreground"));  
+  g_signal_connect (bt_tag_foreground, "color-set", G_CALLBACK (cb_select_tag_color), NULL);
+
+  cb_hl_italic = tea_checkbox (page, _("Italic"), FALSE); 
+  cb_hl_bold = tea_checkbox (page, _("Bold"), FALSE); 
+  cb_hl_underline = tea_checkbox (page, _("Underline"), FALSE); 
+  cb_hl_strikethrough = tea_checkbox (page, _("Strikethrough"), FALSE); 
+
+  g_signal_connect ((gpointer) &cb_hl_italic->toggle_button, "clicked",
+                    G_CALLBACK (cb_hl_italic_toggle),
+                    NULL);
+ 
+  g_signal_connect ((gpointer) &cb_hl_bold->toggle_button, "clicked", //"toggled"
+                    G_CALLBACK (cb_hl_bold_toggle),
+                    NULL);
+
+  g_signal_connect ((gpointer) &cb_hl_underline->toggle_button, "clicked",
+                    G_CALLBACK (cb_hl_underline_toggle),
+                    NULL);
+
+  g_signal_connect ((gpointer) &cb_hl_strikethrough->toggle_button, "clicked",
+                    G_CALLBACK (cb_hl_strikethrough_toggle),
+                    NULL);
+
+  cb_tv_available_hlangs_change (tv_available_hlangs, NULL);
+
+  return page;
+}
+
+
+#endif
+
+
 
 
 static void cb_put_launcher (GtkButton *button,
                              gpointer user_data)
 {
-   free_desktop_create_shortcut ();
+  free_desktop_create_shortcut ();
 }
 
 
 static void cb_del_launcher (GtkButton *button,
                              gpointer user_data)
 {
-   free_desktop_delete_shortcut ();
+  free_desktop_delete_shortcut ();
 }
 
 
@@ -113,28 +364,27 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_str (l, "cm_dvi_to_pdf", gtk_entry_get_text (GTK_ENTRY (ent_cm_dvi_to_pdf)));
 
    l = add_to_glist_combined_str (l, "mplayer", gtk_entry_get_text (GTK_ENTRY (ent_cm_mplayer)));
-   l = add_to_glist_combined_str (l, "mozilla", gtk_entry_get_text (GTK_ENTRY (ent_cm_mozilla)));
-   l = add_to_glist_combined_str (l, "konqueror", gtk_entry_get_text (GTK_ENTRY (ent_cm_konqueror)));
-   l = add_to_glist_combined_str (l, "firefox", gtk_entry_get_text (GTK_ENTRY (ent_cm_firefox)));
-   l = add_to_glist_combined_str (l, "opera", gtk_entry_get_text (GTK_ENTRY (ent_cm_opera)));
-   l = add_to_glist_combined_str (l, "links", gtk_entry_get_text (GTK_ENTRY (ent_cm_links)));
-   l = add_to_glist_combined_str (l, "elinks", gtk_entry_get_text (GTK_ENTRY (ent_cm_elinks)));
-   l = add_to_glist_combined_str (l, "dillo", gtk_entry_get_text (GTK_ENTRY (ent_cm_dillo)));
-   l = add_to_glist_combined_str (l, "galeon", gtk_entry_get_text (GTK_ENTRY (ent_cm_galeon)));
-   l = add_to_glist_combined_str (l, "epiphany", gtk_entry_get_text (GTK_ENTRY (ent_cm_epiphany)));
 
-   l = add_to_glist_combined_str (l, "other", gtk_entry_get_text (GTK_ENTRY (ent_cm_other)));
-   l = add_to_glist_combined_str (l, "lynx", gtk_entry_get_text (GTK_ENTRY (ent_cm_lynx)));
    l = add_to_glist_combined_str (l, "def_doc_browser", gtk_entry_get_text (GTK_ENTRY (ent_cm_manual_browser)));
 
    l = add_to_glist_combined_str (l, "date_time", gtk_entry_get_text (GTK_ENTRY (ent_date_time)));
    l = add_to_glist_combined_str (l, "now_playing", gtk_entry_get_text (GTK_ENTRY (ent_now_playing)));
 
-
    l = add_to_glist_combined_str (l, "tag_color_lm_error_fg", gtk_entry_get_text (GTK_ENTRY (ent_tag_color_lm_error_fg)));
    l = add_to_glist_combined_str (l, "tag_color_lm_error_bg", gtk_entry_get_text (GTK_ENTRY (ent_tag_color_lm_error_bg)));
+
+   l = add_to_glist_combined_str (l, "tag_current_line_fg", gtk_entry_get_text (GTK_ENTRY (ent_tag_current_line_fg)));
+   l = add_to_glist_combined_str (l, "tag_current_line_bg", gtk_entry_get_text (GTK_ENTRY (ent_tag_current_line_bg)));
+
+   l = add_to_glist_combined_int (l, "margin_visible", gtk_toggle_button_get_active (&cb_margin_visible->toggle_button));
+   l = add_to_glist_combined_int (l, "margin_width", gtk_spin_button_get_value_as_int (sb_margin_width)); 
+
    l = add_to_glist_combined_str (l, "color_cursor", gtk_entry_get_text (GTK_ENTRY (ent_color_cursor)));
 
+   l = add_to_glist_combined_str (l, "tag_color_paint_fg", gtk_entry_get_text (GTK_ENTRY (ent_tag_color_paint_fg)));
+   l = add_to_glist_combined_str (l, "tag_color_paint_bg", gtk_entry_get_text (GTK_ENTRY (ent_tag_color_paint_bg)));
+
+
    l = add_to_glist_combined_str (l, "tag_comment", gtk_entry_get_text (GTK_ENTRY (ent_tag_comment)));
    l = add_to_glist_combined_str (l, "tag_identifier", gtk_entry_get_text (GTK_ENTRY (ent_tag_identifier)));
    l = add_to_glist_combined_str (l, "tag_digit", gtk_entry_get_text (GTK_ENTRY (ent_tag_digit)));
@@ -155,15 +405,6 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_str (l, "default_charset", gtk_entry_get_text (GTK_ENTRY (ent_default_charset)));
    l = add_to_glist_combined_str (l, "rtf_enc", gtk_entry_get_text (GTK_ENTRY (ent_rtf_enc)));
 
-/*
-   l = add_to_glist_combined_str (l, "tag_comment_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_comment_font)));
-   l = add_to_glist_combined_str (l, "tag_identifier_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_identifier_font)));
-   l = add_to_glist_combined_str (l, "tag_digit_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_digit_font)));
-   l = add_to_glist_combined_str (l, "tag_string_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_string_font)));
-   l = add_to_glist_combined_str (l, "tag_html_tag_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_html_tag_font)));
-   l = add_to_glist_combined_str (l, "tag_preprocessor_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_preprocessor_font)));
-   l = add_to_glist_combined_str (l, "tag_type_font", gtk_entry_get_text (GTK_ENTRY (ent_tag_type_font)));
-*/
    l = add_to_glist_combined_str (l, "tag_comment_font", gtk_font_button_get_font_name (fb_tag_comment_font));
    l = add_to_glist_combined_str (l, "tag_identifier_font", gtk_font_button_get_font_name (fb_tag_identifier_font));
    l = add_to_glist_combined_str (l, "tag_digit_font", gtk_font_button_get_font_name (fb_tag_digit_font));
@@ -173,15 +414,22 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_str (l, "tag_type_font", gtk_font_button_get_font_name (fb_tag_type_font));
    l = add_to_glist_combined_str (l, "editor_font", gtk_font_button_get_font_name (fb_editor_font));
 
-
-//   l = add_to_glist_combined_str (l, "editor_font", gtk_entry_get_text (GTK_ENTRY (ent_editor_font)));
-
    l = add_to_glist_combined_str (l, "ext_pic_editor", gtk_entry_get_text (GTK_ENTRY (ent_ext_pic_editor)));
    l = add_to_glist_combined_str (l, "ext_pic_viewer", gtk_entry_get_text (GTK_ENTRY (ent_ext_pic_viewer)));
-
-   l = add_to_glist_combined_int (l, "autoclose_tags", gtk_toggle_button_get_active (&cb_autoclose_tags->toggle_button));
    
+   l = add_to_glist_combined_str (l, "def_file_ext", gtk_entry_get_text (GTK_ENTRY (ent_def_file_ext)));
 
+
+   l = add_to_glist_combined_int (l, "common_closing_button_visible", gtk_toggle_button_get_active (&cb_common_closing_button_visible->toggle_button));
+   l = add_to_glist_combined_int (l, "do_crash_file", gtk_toggle_button_get_active (&cb_do_crash_file->toggle_button));
+   l = add_to_glist_combined_int (l, "do_save_all_on_termination", gtk_toggle_button_get_active (&cb_do_save_all_on_termination->toggle_button));
+   l = add_to_glist_combined_int (l, "det_charset_by_meta", gtk_toggle_button_get_active (&cb_det_charset_by_meta->toggle_button));
+   l = add_to_glist_combined_int (l, "do_last_session", gtk_toggle_button_get_active (&cb_autorestore_last_session->toggle_button));
+   l = add_to_glist_combined_int (l, "hl_current_line", gtk_toggle_button_get_active (&cb_hl_current_line->toggle_button));
+   l = add_to_glist_combined_int (l, "do_autosave", gtk_toggle_button_get_active (&cb_do_autosave->toggle_button));
+   l = add_to_glist_combined_int (l, "autoclose_tags", gtk_toggle_button_get_active (&cb_autoclose_tags->toggle_button));
+   l = add_to_glist_combined_int (l, "fullscreen", gtk_toggle_button_get_active (&cb_fullscreen->toggle_button));
+   l = add_to_glist_combined_int (l, "notebook_tab_position", gtk_combo_box_get_active (tv_notetab_positions));
    l = add_to_glist_combined_int (l, "prompt_on_not_saved", gtk_toggle_button_get_active (&cb_prompt_on_not_saved->toggle_button));
    l = add_to_glist_combined_int (l, "prompt_on_file_exists", gtk_toggle_button_get_active (&cb_prompt_on_file_exists->toggle_button));
 
@@ -193,11 +441,16 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "use_snippets", gtk_toggle_button_get_active (&cb_use_snippets->toggle_button));
    l = add_to_glist_combined_int (l, "use_ext_image_viewer", gtk_toggle_button_get_active (&cb_use_ext_image_viewer->toggle_button));
 
+
+
+   l = add_to_glist_combined_int (l, "add_def_file_ext", gtk_toggle_button_get_active (&cb_add_def_file_ext->toggle_button));
+   
+
    l = add_to_glist_combined_int (l, "do_hl_on_fileopen", gtk_toggle_button_get_active (&cb_do_hl_on_fileopen->toggle_button));
    l = add_to_glist_combined_int (l, "do_backup", gtk_toggle_button_get_active (&cb_do_backup->toggle_button));
 
    l = add_to_glist_combined_int (l, "start_with_blank_file", gtk_toggle_button_get_active (&cb_start_with_blank_file->toggle_button));
-   l = add_to_glist_combined_int (l, "start_with_recent_file", gtk_toggle_button_get_active (&cb_start_with_recent_file->toggle_button));
+//   l = add_to_glist_combined_int (l, "start_with_recent_file", gtk_toggle_button_get_active (&cb_start_with_recent_file->toggle_button));
 
    l = add_to_glist_combined_int (l, "use_def_doc_browser", gtk_toggle_button_get_active (&cb_use_def_doc_browser->toggle_button));
 
@@ -229,11 +482,12 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "show_hidden_files", gtk_toggle_button_get_active (&cb_show_hidden_files->toggle_button));
    l = add_to_glist_combined_int (l, "do_autorep", gtk_toggle_button_get_active (&cb_do_autorep->toggle_button));
 
+
+
+   l = add_to_glist_combined_int (l, "autosave_interval", gtk_spin_button_get_value_as_int (sb_autosave_interval));  
    l = add_to_glist_combined_int (l, "logmemo_lines_max", gtk_spin_button_get_value_as_int (sb_logmemo_lines_max));  
-   l = add_to_glist_combined_int (l, "famous_history_max", gtk_spin_button_get_value_as_int (sb_famous_history_max));  
+   //l = add_to_glist_combined_int (l, "famous_history_max", gtk_spin_button_get_value_as_int (sb_famous_history_max));  
    l = add_to_glist_combined_int (l, "max_recent_items", gtk_spin_button_get_value_as_int (sb_max_recent_items));  
-   //l = add_to_glist_combined_int (l, "autocomp_wordlen_min", gtk_spin_button_get_value_as_int (sb_autocomp_wordlen_min));  
-   //l = add_to_glist_combined_int (l, "autocomp_list_items_max", gtk_spin_button_get_value_as_int (sb_autocomp_list_items_max));  
 
    l = add_to_glist_combined_int (l, "thumb_width", gtk_spin_button_get_value_as_int (sb_thumb_width));  
    l = add_to_glist_combined_int (l, "thumb_height", gtk_spin_button_get_value_as_int (sb_thumb_height));  
@@ -243,14 +497,13 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "tab_size", gtk_spin_button_get_value_as_int (sb_tab_size));  
  
    glist_save_to_file (l, confile.tea_rc);
-
    glist_strings_free (l);
    confile_reload ();
    write_gtkrc (); 
    gtk_rc_parse (confile.file_gtkrc);
    gtk_rc_reset_styles (gtk_settings_get_for_screen (gdk_screen_get_default ()));
-
-   doc_update_all();
+   ui_update ();
+   doc_update_all ();
    update_enc_menu();
 }
 
@@ -278,7 +531,9 @@ static GtkWidget* wnd_options_encoding (void)
 
   ent_default_charset = tea_combo (box, confile.iconv_encs, _("Default charset for File open"), confile.default_charset);
   ent_def_filesave_charset = tea_combo (box, confile.gl_save_charsets, _("Default charset for File save as"), confile.def_filesave_charset);
+  ent_rtf_enc = tea_text_entry (box, _("Default charset for RTF"), confile.rtf_enc);  
  
+
   fr1 = gtk_frame_new (_("Misc"));   
   gtk_widget_show (fr1);
   gtk_box_pack_start (box, fr1, FALSE, FALSE, UI_PACKFACTOR);
@@ -287,7 +542,7 @@ static GtkWidget* wnd_options_encoding (void)
   gtk_widget_show (box);
   gtk_container_add (fr1, box); 
 
-  ent_rtf_enc = tea_text_entry (box, _("Default charset for RTF"), confile.rtf_enc);  
+  cb_det_charset_by_meta = tea_checkbox (box, _("Detect a charset by the [X]HTML meta header"), confile.det_charset_by_meta); 
  
   GtkWidget *fr2 = gtk_frame_new (_("Autodetect"));   
   gtk_widget_show (fr2);
@@ -353,6 +608,9 @@ static GtkWidget* wnd_options_commands (void)
   ent_ext_pic_viewer = tea_text_entry (b, _("External image viewer"), confile.ext_pic_viewer);
   ent_cm_mplayer =  tea_text_entry (b, _("Run Mplayer with subtitles"), confile.cm_mplayer);
 
+  ent_cm_manual_browser = tea_text_entry (b, _("Browser for the manual"), confile.cmd_def_doc_browser);
+  cb_use_def_doc_browser = tea_checkbox (b, _("Use this browser"), confile.use_def_doc_browser); 
+
   GtkWidget *fr_latex = gtk_frame_new (_("LaTeX"));
   gtk_widget_show (fr_latex);
   gtk_container_add (page, fr_latex);
@@ -372,19 +630,19 @@ static GtkWidget* wnd_options_commands (void)
   return page;
 }
 
-
+/*
 static GtkWidget* wnd_options_limits (void)
 {
   GtkWidget *page = gtk_vbox_new (FALSE, 1);
   gtk_widget_show (page);
 
-  sb_logmemo_lines_max = tea_spinbutton (page, _("Logmemo lines limit"), confile.logmemo_lines_max);
   sb_famous_history_max = tea_spinbutton (page, _("Text entry history limit"), confile.famous_history_max);
   sb_max_recent_items = tea_spinbutton (page, _("Max. recent files"), confile.max_recent_items); 
-
+ sb_logmemo_lines_max = tea_spinbutton (page, _("Logmemo lines limit"), confile.logmemo_lines_max);
+ 
   return page;
 }
-
+*/
 
 static GtkWidget* wnd_options_functions (void)
 {
@@ -409,6 +667,14 @@ static GtkWidget* wnd_options_interface (void)
   sb_thumb_height = tea_spinbutton (page, _("Image thumbnail height"), confile.thumb_height);
   cb_main_wnd_show_full_path = tea_checkbox (page, _("Show the full path in the window caption"), confile.main_wnd_show_full_path); 
   cb_do_show_main_toolbar = tea_checkbox (page, _("Show the main toolbar"), confile.do_show_main_toolbar); 
+  cb_common_closing_button_visible = tea_checkbox (page, _("Show the common close button"), confile.common_closing_button_visible); 
+  cb_fullscreen = tea_checkbox (page, _("Start in the full-screen mode"), confile.fullscreen); 
+
+  tv_notetab_positions = tea_combo_combo (page, gl_notetab_positions, _("Tabs position"), confile.notebook_tab_position); 
+
+  sb_max_recent_items = tea_spinbutton (page, _("Max. recent files"), confile.max_recent_items); 
+  sb_logmemo_lines_max = tea_spinbutton (page, _("Logmemo lines limit"), confile.logmemo_lines_max);
+ 
 
   return page;
 }
@@ -419,9 +685,20 @@ static GtkWidget* wnd_options_switches (void)
   GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
 
-  cb_start_with_recent_file = tea_checkbox (page, _("Start TEA with a recent file"), confile.start_with_recent_file); 
+  cb_do_crash_file = tea_checkbox (page, _("Save the crashfile on terminate"), confile.do_crash_file); 
+  cb_do_save_all_on_termination = tea_checkbox (page, _("Save all on the abnormal termination (SIGTERM, etc)"), confile.do_save_all_on_termination); 
+  
+  cb_autorestore_last_session = tea_checkbox (page, _("Restore the last session on start"), confile.do_last_session); 
   cb_start_with_blank_file = tea_checkbox (page, _("Start TEA with a blank file"), confile.start_with_blank_file); 
+
   cb_do_det_scripts_by_content = tea_checkbox (page, _("Determine a scripts highlighting by the content"), confile.do_det_scripts_by_content); 
+
+#ifndef CHAI_MODE
+
+gtk_widget_hide (cb_do_det_scripts_by_content);
+  
+#endif
+
   cb_show_hidden_files = tea_checkbox (page, _("Show hidden files in Kwas"), confile.show_hidden_files); 
   cb_use_snippets = tea_checkbox (page, _("Use snippets"), confile.use_snippets); 
   cb_use_ext_image_viewer = tea_checkbox (page, _("Use external image viewer"), confile.use_ext_image_viewer);
@@ -457,6 +734,32 @@ static void cb_backup_config (GtkButton *button,
 }
 
 
+static void cb_change_all_fonts (GtkButton *button,
+                                gpointer user_data)
+{
+  GtkFontSelectionDialog *w = gtk_font_selection_dialog_new (_("Please select the font"));
+  gchar *font_name;
+
+  if (gtk_dialog_run (GTK_DIALOG (w)) == GTK_RESPONSE_OK)
+    {
+     font_name = gtk_font_selection_dialog_get_font_name (w);
+     if (font_name)
+       {
+        gtk_font_button_set_font_name (fb_tag_comment_font, font_name);
+        gtk_font_button_set_font_name (fb_tag_identifier_font, font_name);
+        gtk_font_button_set_font_name (fb_tag_digit_font, font_name);
+        gtk_font_button_set_font_name (fb_tag_string_font, font_name);
+        gtk_font_button_set_font_name (fb_tag_html_tag_font, font_name);
+        gtk_font_button_set_font_name (fb_tag_preprocessor_font, font_name);
+        gtk_font_button_set_font_name (fb_tag_type_font, font_name);
+        gtk_font_button_set_font_name (fb_editor_font, font_name);
+        g_free (font_name);
+       }
+     }
+
+  gtk_widget_destroy (w);
+}
+
 static void cb_restore_config (GtkButton *button,
                                gpointer user_data)
 {
@@ -478,7 +781,7 @@ static void cb_config_reset (GtkButton *button,
        confile_reload ();
        doc_update_all();
        update_enc_menu();
-       dlg_info (wnd_options, _("Configuration reseted to default, please close and reopen the Preferences window."), NULL);  
+       dlg_info (wnd_options, _("Configuration is reseted to default, please close and reopen the Preferences window."), NULL);  
       }  
 }
 
@@ -514,6 +817,12 @@ static GtkWidget* wnd_options_colors (void)
   ent_text_sel_background = tea_color_selector (page, _("Selected background"), confile.text_sel_background);
   ent_color_cursor = tea_color_selector (page, _("Cursor color"), confile.color_cursor);
 
+  ent_tag_color_paint_fg = tea_color_selector (page, _("Marking function foreground"), confile.tag_color_paint_fg);
+  ent_tag_color_paint_bg = tea_color_selector (page, _("Marking function background"), confile.tag_color_paint_bg);
+
+  ent_tag_current_line_fg = tea_color_selector (page, _("Current line foreground"), confile.tag_current_line_fg);
+  ent_tag_current_line_bg = tea_color_selector (page, _("Current line background"), confile.tag_current_line_bg);
+
   ent_tag_spellcheck = tea_color_selector (page, _("Spellchecker marks"), confile.tag_spellcheck);
   
   page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
@@ -528,6 +837,12 @@ static GtkWidget* wnd_options_colors (void)
   ent_tag_preprocessor = tea_color_selector (page, _("Preprocessor"), confile.tag_preprocessor);
   ent_tag_type = tea_color_selector (page, _("Types"), confile.tag_type);
 
+  #ifdef CHAI_MODE
+
+  gtk_widget_hide (page);
+  
+  #endif
+
   page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
   gtk_notebook_append_page (notebook, page, gtk_label_new (_("IDE")));
@@ -544,17 +859,12 @@ static GtkWidget* wnd_options_fonts (void)
   GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
 
-//  ent_editor_font = tea_font_selector (page, _("Editor font"), confile.editor_font); 
-/*
-  ent_tag_comment_font = tea_font_selector (page, _("Comments font"), confile.tag_comment_font); 
-  ent_tag_identifier_font = tea_font_selector (page, _("Identifiers font"), confile.tag_identifier_font); 
-  ent_tag_digit_font = tea_font_selector (page, _("Digits font"), confile.tag_digit_font); 
-  ent_tag_string_font = tea_font_selector (page, _("Strings font"), confile.tag_string_font); 
-  ent_tag_html_tag_font = tea_font_selector (page, _("HTML tags font"), confile.tag_html_tag_font); 
-  ent_tag_preprocessor_font = tea_font_selector (page, _("Preprocessor font"), confile.tag_preprocessor_font); 
-  ent_tag_type_font = tea_font_selector (page, _("Types font"), confile.tag_type_font); 
-  */
+#ifndef CHAI_MODE
+
   fb_editor_font = tea_font_button (page, _("Editor font"), confile.editor_font); 
+
+#endif
+
   fb_tag_comment_font = tea_font_button (page, _("Comments font"), confile.tag_comment_font); 
   fb_tag_identifier_font = tea_font_button (page, _("Identifiers font"), confile.tag_identifier_font); 
   fb_tag_digit_font = tea_font_button (page, _("Digits font"), confile.tag_digit_font); 
@@ -562,30 +872,9 @@ static GtkWidget* wnd_options_fonts (void)
   fb_tag_html_tag_font = tea_font_button (page, _("HTML tags font"), confile.tag_html_tag_font); 
   fb_tag_preprocessor_font = tea_font_button (page, _("Preprocessor font"), confile.tag_preprocessor_font); 
   fb_tag_type_font = tea_font_button (page, _("Types font"), confile.tag_type_font); 
+
+  GtkButton *bt_change_all_fonts = tea_button_at_box (page, _("Change all fonts"), cb_change_all_fonts, NULL);
  
-
-  return page;
-}
-
-
-static GtkWidget* wnd_options_browsers (void)
-{
-  GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
-  gtk_widget_show (page);
-  ent_cm_opera = tea_text_entry (page, "Opera", confile.cmd_Opera);
-  ent_cm_konqueror = tea_text_entry (page, "Konqueror", confile.cmd_Konqueror);
-  ent_cm_firefox = tea_text_entry (page, "Firefox", confile.cmd_Firefox);
-  ent_cm_mozilla = tea_text_entry (page, "Mozilla",  confile.cmd_Mozilla);
-  ent_cm_links = tea_text_entry (page, "Links", confile.cmd_Links); 
-  ent_cm_elinks = tea_text_entry (page, "Elinks", confile.cmd_ELinks);
-  ent_cm_dillo = tea_text_entry (page, "Dillo", confile.cmd_Dillo);
-  ent_cm_galeon = tea_text_entry (page, "Galeon", confile.cmd_Galeon);
-  ent_cm_epiphany = tea_text_entry (page, "Epiphany", confile.cmd_Epiphany); 
-  ent_cm_other = tea_text_entry (page, "Other", confile.cmd_Other);
-  ent_cm_lynx = tea_text_entry (page, "Lynx", confile.cmd_Lynx);
-  ent_cm_manual_browser = tea_text_entry (page, _("Browser for the manual"), confile.cmd_def_doc_browser);
-  cb_use_def_doc_browser = tea_checkbox (page, _("Use this browser"), confile.use_def_doc_browser); 
-
   return page;
 }
 
@@ -594,13 +883,34 @@ static GtkWidget* wnd_options_editor (void)
 {
   GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
-  ent_def_markup_mode = tea_combo (page, gl_supported_markup_modes, _("Default markup mode"), confile.default_markup_mode);
+ 
+#ifdef CHAI_MODE
+
+  fb_editor_font = tea_font_button (page, _("Font"), confile.editor_font); 
+
+#endif
+
+  ent_def_markup_mode = tea_combo (page, gl_markup_modes, _("Default markup mode"), confile.default_markup_mode);
+
   sb_tab_size = tea_spinbutton (page, _("Tab size in spaces"), confile.tab_size);
   cb_ins_spaces_on_tab_press = tea_checkbox (page, _("Insert spaces on TAB key"), confile.ins_spaces_on_tab_press);
   cb_use_auto_indent = tea_checkbox (page, _("Automatic indent"), confile.use_auto_indent);
   cb_do_autorep = tea_checkbox (page, _("Autoreplace"), confile.do_autorep);
   cb_autoclose_tags = tea_checkbox (page, _("Autoclose tags"), confile.autoclose_tags);  
   cb_use_cursor_blink = tea_checkbox (page, _("Cursor blink"), confile.use_cursor_blink);  
+  sb_autosave_interval = tea_spinbutton (page, _("Autosaving interval, minutes"), confile.autosave_interval);
+  cb_do_autosave = tea_checkbox (page, _("Enable the autosaving"), confile.do_autosave);
+  cb_hl_current_line = tea_checkbox (page, _("Highlight the current line"), confile.hl_current_line);
+
+  cb_margin_visible = tea_checkbox (page, _("Show the margin"), confile.margin_visible);  
+  sb_margin_width = tea_spinbutton (page, _("Position of the margin (GtkSourceView-only)"), confile.margin_width);
+
+#ifndef CHAI_MODE
+
+  gtk_widget_hide (cb_margin_visible);
+  
+#endif
+
 
   return page;
 }
@@ -615,6 +925,10 @@ static GtkWidget* wnd_options_paths (void)
   ent_def_open_dir = tea_dir_selector (page, _("Default file opening directory"), confile.def_open_dir);
   cb_use_def_open_dir = tea_checkbox (page, _("Use default file opening directory"), confile.use_def_open_dir);
   
+  cb_add_def_file_ext = tea_checkbox (page, _("Add this extension to the file which is *Saving as*"), confile.add_def_file_ext);
+  ent_def_file_ext = tea_text_entry (page, _("(<i>for example, txt, html, etc</i>)"), confile.def_file_ext);
+
+
   return page;
 }
 
@@ -640,11 +954,29 @@ GtkWidget* wnd_options_create (void)
   gtk_notebook_append_page (notebook, wnd_options_encoding (), gtk_label_new (_("Encoding")));
   gtk_notebook_append_page (notebook, wnd_options_functions (), gtk_label_new (_("Functions")));
   gtk_notebook_append_page (notebook, wnd_options_interface (), gtk_label_new (_("Interface")));
-  gtk_notebook_append_page (notebook, wnd_options_limits (), gtk_label_new (_("Limits")));
-  gtk_notebook_append_page (notebook, wnd_options_fonts (), gtk_label_new (_("Fonts")));
+//  gtk_notebook_append_page (notebook, wnd_options_limits (), gtk_label_new (_("Limits")));
+
+  page_fonts = wnd_options_fonts ();
+
+#ifndef CHAI_MODE
+
+  gtk_notebook_append_page (notebook, page_fonts, gtk_label_new (_("Fonts")));
+
+#endif
+  
   gtk_notebook_append_page (notebook, wnd_options_editor (), gtk_label_new (_("Editor")));
-  gtk_notebook_append_page (notebook, wnd_options_browsers (), gtk_label_new (_("Browsers")));
+
+#ifdef CHAI_MODE
+
+//n.p. THe Pixies - Manta Ray
+
+ gtk_notebook_append_page (notebook, wnd_options_hl_chai (), gtk_label_new (_("Highlighting")));
+  
+#endif
+
   gtk_notebook_append_page (notebook, wnd_options_colors (), gtk_label_new (_("Colors")));
+
+
   gtk_notebook_append_page (notebook, wnd_options_commands (), gtk_label_new (_("Commands")));
   gtk_notebook_append_page (notebook, wnd_options_paths (), gtk_label_new (_("Paths")));
   gtk_notebook_append_page (notebook, wnd_options_confirmations (), gtk_label_new (_("Confirmations")));
